import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko_system/buttons/button.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';
import 'package:rothko_mobile/rothko_system/utilities/textstyles.dart';

class RothkoBottomSheetConfirmation extends StatelessWidget {
  final String header, body;
  final Widget? imageWidget;
  final bool? doubleCta, secondaryBtnLoading, primaryBtnLoading, expand, snap;
  final String? secondaryBtnText, primaryBtnText;
  final Function()? secondaryBtnOnTap, primaryBtnOnTap;
  final double? initialChildSize, minChildSize, maxChildSize;
  const RothkoBottomSheetConfirmation(
      {Key? key,
      required this.header,
      required this.body,
      this.imageWidget,
      this.primaryBtnLoading,
      this.secondaryBtnLoading,
      this.primaryBtnText,
      this.primaryBtnOnTap,
      this.secondaryBtnOnTap,
      this.secondaryBtnText,
      this.expand,
      this.snap,
      this.initialChildSize,
      this.maxChildSize,
      this.minChildSize,
      required this.doubleCta})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      persistentFooterButtons: [
        Container(
          child: doubleCta!
              ? Row(mainAxisAlignment: MainAxisAlignment.center, children: [
                  Expanded(
                    child: RothkoButton(
                        fullScreen: true,
                        loading: secondaryBtnLoading ?? false,
                        size: ButtonSize.LARGE,
                        filled: true,
                        onPressed: () =>
                            secondaryBtnOnTap ?? Navigator.pop(context),
                        color: RothkoColor.kLightNeutralLighten2,
                        textColor: RothkoColor.kPrimaryBase,
                        text: secondaryBtnText ?? 'Button text'),
                  ),
                  SizedBox(
                    width: 8,
                  ),
                  Expanded(
                    child: RothkoButton(
                      fullScreen: true,
                      loading: primaryBtnLoading ?? false,
                      size: ButtonSize.LARGE,
                      filled: true,
                      onPressed: () => primaryBtnOnTap,
                      color: RothkoColor.kPrimaryBase,
                      text: primaryBtnText ?? 'Button Text',
                    ),
                  )
                ])
              : RothkoButton(
                  loading: primaryBtnLoading ?? false,
                  filled: true,
                  fullScreen: true,
                  onPressed: () => primaryBtnOnTap,
                  color: RothkoColor.kPrimaryBase,
                  text: primaryBtnText ?? 'Button Text',
                ),
        )
      ],
      body: DraggableScrollableSheet(
          initialChildSize: initialChildSize ?? 0.5,
          minChildSize: minChildSize ?? 0.4,
          maxChildSize: maxChildSize ?? 1.0,
          expand: expand ?? true,
          snap: snap ?? false,
          builder: (BuildContext context, scrollController) {
            return Container(
              padding: EdgeInsets.symmetric(horizontal: 16.0),
              decoration: BoxDecoration(
                  color: Colors.white,
                  borderRadius: BorderRadius.only(
                      topLeft: Radius.circular(8),
                      topRight: Radius.circular(8))),
              child: ListView(
                controller: scrollController,
                children: [
                  Column(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: [
                      SizedBox(
                        height: 16,
                      ),
                      Container(
                        width: 32.0,
                        height: 4.0,
                        decoration: BoxDecoration(
                          borderRadius: BorderRadius.circular(8),
                          color: RothkoColor.kLightNeutralDarken1,
                        ),
                      ),
                      SizedBox(
                        height: 24.0,
                      ),
                      Container(
                        height: 64.0,
                        width: 64.0,
                        decoration: BoxDecoration(
                            borderRadius: BorderRadius.circular(8),
                            color: RothkoColor.kLightNeutralBase),
                        child: imageWidget,
                      ),
                      SizedBox(
                        height: 16.0,
                      ),
                      Text(
                        header,
                        style: RothkoTextStyles.h3,
                      ),
                      SizedBox(
                        height: 8,
                      ),
                      Padding(
                        padding: const EdgeInsets.symmetric(horizontal: 16.0),
                        child: Text(
                          body,
                          style: RothkoTextStyles.bodyText2,
                          textAlign: TextAlign.center,
                        ),
                      ),
                      SizedBox(
                        height: 24.0,
                      ),
                    ],
                  )
                ],
              ),
            );
          }),
    );
  }
}
