import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko_system/buttons/button.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';
import 'package:rothko_mobile/rothko_system/utilities/textstyles.dart';

class RothkoBottomSheetStandard extends StatelessWidget {
  final String header;
  final String? subtitle;
  final Widget? content;
  final bool? doubleCta, secondaryBtnLoading, primaryBtnLoading, expand, snap;
  final String? secondaryBtnText, primaryBtnText;
  final Function()? secondaryBtnOnTap, primaryBtnOnTap;
  final double? initialChildSize, minChildSize, maxChildSize;

  const RothkoBottomSheetStandard(
      {Key? key,
      required this.header,
      this.subtitle,
      this.primaryBtnLoading,
      this.primaryBtnOnTap,
      this.secondaryBtnLoading,
      this.secondaryBtnOnTap,
      this.primaryBtnText,
      this.secondaryBtnText,
      this.expand,
      this.snap,
      this.initialChildSize,
      this.maxChildSize,
      this.minChildSize,
      required this.content,
      required this.doubleCta})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      persistentFooterButtons: [
        Container(
          child: doubleCta!
              ? Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: [
                        Expanded(
                          child: RothkoButton(
                              fullScreen: true,
                              loading: secondaryBtnLoading ?? false,
                              size: ButtonSize.LARGE,
                              filled: true,
                              onPressed: () =>
                                  secondaryBtnOnTap ?? Navigator.pop(context),
                              color: RothkoColor.kLightNeutralLighten2,
                              textColor: RothkoColor.kPrimaryBase,
                              text: secondaryBtnText ?? 'Button text'),
                        ),
                        SizedBox(
                          width: 8,
                        ),
                        Expanded(
                          child: RothkoButton(
                            fullScreen: true,
                            loading: primaryBtnLoading ?? false,
                            size: ButtonSize.LARGE,
                            filled: true,
                            onPressed: () => primaryBtnOnTap,
                            color: RothkoColor.kPrimaryBase,
                            text: primaryBtnText ?? 'Button Text',
                          ),
                        )
                      ]),
                )
              : RothkoButton(
                  loading: primaryBtnLoading ?? false,
                  filled: true,
                  fullScreen: true,
                  onPressed: () => primaryBtnOnTap,
                  color: RothkoColor.kPrimaryBase,
                  text: primaryBtnText ?? 'Button Text',
                ),
        )
      ],
      body: DraggableScrollableSheet(
          initialChildSize: initialChildSize ?? 0.6,
          minChildSize: minChildSize ?? 0.5,
          maxChildSize: maxChildSize ?? 1.0,
          expand: expand ?? true,
          snap: snap ?? false,
          builder: (BuildContext context, ScrollController scrollController) {
            return Container(
              padding: EdgeInsets.symmetric(horizontal: 16.0),
              decoration: BoxDecoration(
                  color: Colors.white,
                  borderRadius: BorderRadius.only(
                      topLeft: Radius.circular(8),
                      topRight: Radius.circular(8))),
              child: ListView(
                controller: scrollController,
                children: [
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      SizedBox(
                        height: 16,
                      ),
                      Center(
                        child: Container(
                          height: 4.0,
                          width: 32.0,
                          color: RothkoColor.kLightNeutralDarken1,
                        ),
                      ),
                      SizedBox(
                        height: 24.0,
                      ),
                      Text(
                        header,
                        style: RothkoTextStyles.h3,
                      ),
                      SizedBox(
                        height: 8,
                      ),
                      Text(
                        subtitle!,
                        style: RothkoTextStyles.bodyText2,
                        textAlign: TextAlign.center,
                      ),
                      SizedBox(
                        height: 24.0,
                      ),
                      Container(
                        child: content,
                      ),
                    ],
                  ),
                ],
              ),
            );
          }),
    );
  }
}
