import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';
import 'package:rothko_mobile/rothko_system/utilities/textstyles.dart';

class RothkoAvatar extends StatelessWidget {
  final String? urlType;
  final AvatarSize size;
  final String name;
  final Color color;
  final bool? showBorder;
  final Color? borderColor;

  RothkoAvatar({
    this.urlType,
    required this.size,
    required this.name,
    required this.color,
    this.showBorder,
    this.borderColor,
  });
  @override
  Widget build(BuildContext context) {
    bool isNetWorkFile = false;
    String userInitials = "";
    bool isSvg = false;
    name.split(" ").forEach((element) {
      if (element.isNotEmpty) {
        userInitials += element[0].toString().toUpperCase();
      }
    });

    if (urlType != null) {
      isNetWorkFile =
          urlType!.contains("https://") || urlType!.contains("http://");
      isSvg = urlType!.contains(".svg");
    }

    return Container(
      height: getAvatarSize(size),
      width: getAvatarSize(size),
      decoration: BoxDecoration(
        border: Border.all(
          width: showBorder == true ? 1.5 : 0,
          color: showBorder == true
              ? borderColor ?? RothkoColor.kLightNeutralLighten2
              : Colors.transparent,
        ),
        shape: BoxShape.circle,
        color: color,
      ),
      child: ClipRRect(
        borderRadius: BorderRadius.circular(getAvatarSize(size)) / 2,
        child: Center(
          child: isNetWorkFile
              ? isSvg
                  ? SvgPicture.network(urlType!)
                  : Image.network(urlType!)
              : isSvg
                  ? SvgPicture.asset(urlType!)
                  : urlType == null
                      ? Text(
                          userInitials,
                          style: RothkoTextStyles.overline.copyWith(
                              fontWeight: FontWeight.w500,
                              color: RothkoColor.kLightNeutralLighten2,
                              letterSpacing: 0.02,
                              fontSize: size == AvatarSize.small ||
                                      size == AvatarSize.normal
                                  ? 10
                                  : size == AvatarSize.large
                                      ? 14
                                      : 24),
                        )
                      : Image.asset(urlType!),
        ),
      ),
    );
  }
}

enum AvatarSize { small, normal, large, xLarge, xxLarge }
double getAvatarSize(AvatarSize size) {
  switch (size) {
    case AvatarSize.small:
      return 24;
    case AvatarSize.normal:
      return 32;
    case AvatarSize.large:
      return 56;
    case AvatarSize.xLarge:
      return 80;
    case AvatarSize.xxLarge:
      return 120;
  }
}
