import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko.dart';
import 'package:rothko_mobile/rothko_system/utilities/textstyles.dart';

class RothkoGroupAvatar extends StatelessWidget {
  const RothkoGroupAvatar({
    Key? key,
    required this.namesAndImages,
    this.showBorder,
    this.size = AvatarSize.normal,
    required this.color,
    this.numberofDisplayAvatar,
    this.borderColor,
  }) : super(key: key);
  final List<String> namesAndImages;
  final bool? showBorder;
  final AvatarSize size;
  final Color color;
  final int? numberofDisplayAvatar;
  final Color? borderColor;

  @override
  Widget build(BuildContext context) {
    double width = size == AvatarSize.normal ? 32 : 24;
    double overLap = size == AvatarSize.normal ? 24 : 18;
    double extraWidth =
        (namesAndImages.length > (numberofDisplayAvatar ?? 3)) ? 18 : 0;
    return Container(
      width: (overLap *
              (namesAndImages.length < (numberofDisplayAvatar ?? 3)
                  ? namesAndImages.length
                  : (numberofDisplayAvatar ?? 3))) +
          (width + diff(namesAndImages.length - (numberofDisplayAvatar ?? 3))),
      height: width,
      child: Row(
        children: [
          Expanded(
            child: Stack(
              children: [
                ...List.generate(
                    (namesAndImages.length < (numberofDisplayAvatar ?? 3))
                        ? namesAndImages.length
                        : numberofDisplayAvatar ?? 3, (index) {
                  String value = namesAndImages[index];
                  return Positioned(
                    right: overLap * index,
                    child: Row(
                      children: [
                        RothkoAvatar(
                          urlType: isFile(value) ? value : null,
                          size: size,
                          name: value,
                          color: color,
                          showBorder: showBorder,
                        ),
                      ],
                    ),
                  );
                }),
              ],
            ),
          ),
          SizedBox(
            width: 4,
          ),
          if (namesAndImages.length > (numberofDisplayAvatar ?? 3))
            Text(
              " +${namesAndImages.length - (numberofDisplayAvatar ?? 3)}",
              style: RothkoTextStyles.caption.copyWith(
                letterSpacing: 0.02,
                color: RothkoColor.kDarkNeutralbase,
              ),
            ),
        ],
      ),
    );
  }
}

bool isFile(String? urlType) {
  if (urlType == null) {
    return false;
  }
  bool isNetWorkFile =
      urlType.contains("https://") || urlType.contains("http://");
  bool isSvg = urlType.contains(".svg");
  bool isPng = urlType.contains(".png");
  bool jpegJpg = urlType.contains(".jp");

  return isNetWorkFile || isPng || isSvg || jpegJpg;
}

num diff(num value) {
  if (value < 10) {
    return -5;
  } else if (value < 100) {
    return 3;
  } else if (value < 1000) {
    return 8;
  } else if (value < 10000) {
    return 13;
  }
  return 18;
}
