import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';
import 'package:rothko_mobile/rothko_system/utilities/textstyles.dart';

enum BadgeType { MUTED, PRONOUNCED, ANNOUNCEMENT }
enum BadgeSize { LARGE, NORMAL, SMALL }

// ignore: must_be_immutable
class RothkoBadge extends StatelessWidget {
  final Color? bgColor;

  final Color? textColor;
  final BadgeType? badgeType;
  final double? fontSize;
  final BadgeSize? badgeSize;

  final String? text;

  final bool? primary;

  RothkoBadge(
      {this.bgColor = RothkoColor.kErrorLighten1,
      this.text,
      this.fontSize = 12,
      this.badgeSize = BadgeSize.NORMAL,
      this.badgeType = BadgeType.PRONOUNCED,
      this.primary = false,
      this.textColor = RothkoColor.kLightNeutralLighten2});
  @override
  Widget build(BuildContext context) {
    if (badgeSize == BadgeSize.SMALL) {
      return Container(
        height: 8,
        width: 8,
        decoration: BoxDecoration(color: bgColor, shape: BoxShape.circle),
      );
    }
    return Container(
      height: badgeSize == BadgeSize.NORMAL ? 16 : 20,
      padding: EdgeInsets.symmetric(
        horizontal: badgeSize == BadgeSize.NORMAL ? 4 : 8,
        vertical: badgeSize == BadgeSize.NORMAL ? 0 : 2,
      ),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(4),
        color: badgeType == BadgeType.MUTED
            ? RothkoColor.kLightNeutralBase
            : badgeType == BadgeType.ANNOUNCEMENT
                ? RothkoColor.kSuccessBase
                : bgColor,
      ),
      child: Text(text ?? '',
          style: RothkoTextStyles.caption.copyWith(
              fontSize: fontSize,
              color: badgeType == BadgeType.MUTED
                  ? RothkoColor.kDarkNeutralbase
                  : textColor)),
    );
  }
}
