import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';
import 'package:rothko_mobile/rothko_system/utilities/textstyles.dart';

class RothkoBanner extends StatelessWidget {
  final String? message, subHeading, buttonText;
  final IconData bannerIcon;
  final Color iconColor, bannerColor;
  final bool isInlineBanner, isDismissable;

  final void Function()? onPressed;

  RothkoBanner({
    this.buttonText,
    @required this.message,
    required this.isInlineBanner,
    required this.isDismissable,
    this.subHeading,
    required this.bannerIcon,
    required this.iconColor,
    required this.bannerColor,
    this.onPressed,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        color: bannerColor,
        border: isInlineBanner || isDismissable
            ? null
            : Border(top: BorderSide(color: iconColor, width: 2)),
      ),
      width: MediaQuery.of(context).size.width,
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              isDismissable
                  ? SizedBox()
                  : Padding(
                      padding: const EdgeInsets.only(top: 16.0, left: 12.0),
                      child: Icon(
                        bannerIcon,
                        size: 20.0,
                        color: iconColor,
                      ),
                    ),
              SizedBox(
                width: isDismissable ? 0.0 : 8.0,
              ),
              Container(
                padding: EdgeInsets.symmetric(horizontal: 12.0, vertical: 8.0),
                width: isDismissable
                    ? MediaQuery.of(context).size.width * .80
                    : MediaQuery.of(context).size.width * 0.85,
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    isInlineBanner && !isDismissable
                        ? SizedBox()
                        : Text(
                            subHeading!,
                            style: RothkoTextStyles.s2,
                          ),
                    SizedBox(
                      height: 4.0,
                    ),
                    Text(message!,
                        style: RothkoTextStyles.caption
                            .copyWith(letterSpacing: 0.2)),
                    SizedBox(
                      height: 8.0,
                    ),
                    isInlineBanner || isDismissable
                        ? SizedBox()
                        : TextButton(
                            onPressed: onPressed,
                            style:
                                TextButton.styleFrom(padding: EdgeInsets.zero),
                            child: Text(
                              buttonText ?? 'Go to Settings',
                              style: RothkoTextStyles.s2
                                  .copyWith(color: RothkoColor.kPrimaryBase),
                            ))
                  ],
                ),
              ),
              isDismissable
                  ? IconButton(
                      padding: EdgeInsets.zero,
                      onPressed: () => Navigator.pop,
                      icon: Icon(
                        Icons.close,
                        color: RothkoColor.kDarkNeutralbase,
                        size: 24,
                      ))
                  : SizedBox()
            ],
          ),
        ],
      ),
    );
  }
}
