import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko_system/buttons/button-tap.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';
import 'package:rothko_mobile/rothko_system/utilities/textstyles.dart';

/// Indicates if Button size is going to be [Small],[Normal], [Large] or [Xlarge]
enum ButtonSize { SMALL, NORMAL, LARGE }

// Indicates if Button type is going to be [FAB],[PRIMARY] or [ICON]
enum ButtonType { FAB, PRIMARY, ICON }

class RothkoButton extends StatefulWidget {
  Color textColor;
  Color color;
  Color? indicatorColor;
  Color? indicatorValueColor;
  Color? borderColor;
  bool? filled;
  double? fontSize;
  bool disabled;

  Widget? buttonIcon;

  bool? border;
  String? text;
  ButtonSize? size;
  bool? fullScreen;
  bool? loading;
  bool? hasBeenPressed;
  double? height;

  void Function()? onPressed;

  RothkoButton({
    this.disabled = false,
    this.filled = false,
    this.text = 'Button',
    this.fontSize,
    this.fullScreen = false,
    this.color = kPrimaryBase,
    this.indicatorColor,
    this.indicatorValueColor,
    this.borderColor,
    this.textColor = kPrimaryLighten0,
    this.size = ButtonSize.NORMAL,
    this.border = true,
    this.loading = false,
    this.hasBeenPressed = false,
    this.buttonIcon,
    this.onPressed,
    this.height,
  });
  @override
  _RothkoButtonState createState() => _RothkoButtonState();
}

class _RothkoButtonState extends State<RothkoButton>
    with SingleTickerProviderStateMixin {
  AnimationController? _animationController;
  Animation<double>? _scaleAnimation;
  Duration duration = const Duration(milliseconds: 80);
  double _opacity = 1;

  @override
  void initState() {
    super.initState();
    _animationController = AnimationController(vsync: this, duration: duration);
    _scaleAnimation =
        Tween<double>(begin: 1, end: 0.94).animate(_animationController!);
  }

  @override
  void dispose() {
    _animationController!.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    double w = MediaQuery.of(context).size.width;
    return ButtonTap(
      disabled: widget.disabled,
      onTap: widget.loading! || widget.disabled
          ? () {}
          : widget.onPressed ??
              () {
                setState(() {
                  widget.hasBeenPressed = !widget.hasBeenPressed!;
                });
              },
      child: widget.size == ButtonSize.SMALL
          ? Container(
              constraints: BoxConstraints(minWidth: 160.0),
              height: 48,
              width: widget.fullScreen! ? w : null,
              decoration: BoxDecoration(
                color: getButtonColor(
                    color: widget.color,
                    disabled: widget.disabled,
                    filled: widget.filled!,
                    hasBeenPressed: widget.hasBeenPressed!),
                border: widget.border!
                    ? Border.all(
                        width: 1.0,
                        color: widget.disabled
                            ? RothkoColor.kLightNeutralBase
                            : widget.filled == true
                                ? widget.color
                                : widget.borderColor != null
                                    ? widget.borderColor!
                                    : widget.color,
                      )
                    : Border(),
                borderRadius: BorderRadius.only(
                    topRight: Radius.circular(4),
                    bottomLeft: Radius.circular(4),
                    bottomRight: Radius.circular(4),
                    topLeft: Radius.circular(4)),
              ),
              padding: EdgeInsets.symmetric(horizontal: 0, vertical: 7.5),
              child: widget.loading!
                  ? Container(
                      width: 20,
                      height: 20,
                      decoration: BoxDecoration(shape: BoxShape.circle),
                      padding:
                          EdgeInsets.symmetric(horizontal: 14, vertical: 2),
                      child: SizedBox(
                        height: 15,
                        width: 15,
                        child: widget.fullScreen!
                            ? Center(
                                heightFactor: 1,
                                widthFactor: 1,
                                child: CircularProgressIndicator(
                                  backgroundColor: widget.indicatorColor != null
                                      ? widget.indicatorColor!
                                      : Colors.transparent,
                                  valueColor: AlwaysStoppedAnimation<Color>(
                                      widget.indicatorValueColor != null
                                          ? widget.indicatorValueColor!
                                          : Colors.white),
                                  strokeWidth: 3,
                                ),
                              )
                            : CircularProgressIndicator(
                                backgroundColor: widget.indicatorColor != null
                                    ? widget.indicatorColor!
                                    : Colors.transparent,
                                valueColor: AlwaysStoppedAnimation<Color>(
                                    widget.indicatorValueColor != null
                                        ? widget.indicatorValueColor!
                                        : Colors.white),
                                strokeWidth: 3,
                              ),
                      ),
                    )
                  : Row(
                      mainAxisSize: MainAxisSize.min,
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.center,
                      children: [
                        Flexible(
                          child: Text(
                            widget.text!,
                            textAlign: TextAlign.center,
                            style: RothkoTextStyles.s2.copyWith(
                                color: widget.disabled && widget.filled!
                                    ? RothkoColor.kDarkNeutralLighten1
                                    : widget.disabled && !widget.filled!
                                        ? RothkoColor.kDarkNeutralLighten2
                                        : widget.textColor,
                                fontSize: widget.fontSize ?? 14,
                                fontWeight: FontWeight.w500,
                                fontFamily: "Graphik",
                                height: 1,
                                decoration: TextDecoration.none),
                          ),
                        ),
                        widget.buttonIcon != null
                            ? SizedBox(
                                width: 9.1,
                              )
                            : SizedBox.shrink(),
                        widget.buttonIcon ?? SizedBox.shrink(),
                      ],
                    ),
            )
          : widget.size == ButtonSize.NORMAL
              ? Container(
                  alignment: Alignment.center,
                  width: widget.fullScreen! ? w : null,
                  height: widget.height ?? 40,
                  constraints: BoxConstraints(minWidth: 169),
                  decoration: BoxDecoration(
                      color: getButtonColor(
                          color: widget.color,
                          disabled: widget.disabled,
                          filled: widget.filled!,
                          hasBeenPressed: widget.hasBeenPressed!),
                      border: widget.border!
                          ? Border.all(
                              width: 1.0,
                              color: widget.disabled
                                  ? RothkoColor.kLightNeutralBase
                                  : widget.filled == true
                                      ? widget.color
                                      : widget.borderColor != null
                                          ? widget.borderColor!
                                          : widget.color,
                            )
                          : Border(),
                      borderRadius: widget.filled!
                          ? BorderRadius.circular(4)
                          : BorderRadius.circular(4)),
                  padding: EdgeInsets.symmetric(
                      horizontal: widget.fullScreen != true ? 24 : 0,
                      vertical: 4),
                  child: widget.loading!
                      ? Container(
                          width: 20,
                          height: 20,
                          decoration: BoxDecoration(shape: BoxShape.circle),
                          child: widget.fullScreen!
                              ? Center(
                                  widthFactor: 1,
                                  heightFactor: 1,
                                  child: CircularProgressIndicator(
                                    backgroundColor:
                                        widget.indicatorColor != null
                                            ? widget.indicatorColor!
                                            : Colors.transparent,
                                    valueColor: AlwaysStoppedAnimation<Color>(
                                        widget.indicatorValueColor != null
                                            ? widget.indicatorValueColor!
                                            : Colors.white),
                                    strokeWidth: 3,
                                  ),
                                )
                              : CircularProgressIndicator(
                                  backgroundColor: widget.indicatorColor != null
                                      ? widget.indicatorColor!
                                      : Colors.transparent,
                                  valueColor: AlwaysStoppedAnimation<Color>(
                                      widget.indicatorValueColor != null
                                          ? widget.indicatorValueColor!
                                          : Colors.white),
                                  strokeWidth: 3,
                                ),
                        )
                      : Row(
                          mainAxisSize: MainAxisSize.min,
                          mainAxisAlignment: widget.fullScreen!
                              ? MainAxisAlignment.center
                              : MainAxisAlignment.start,
                          crossAxisAlignment: CrossAxisAlignment.center,
                          children: [
                            Flexible(
                              child: Text(
                                widget.text!,
                                textAlign: TextAlign.center,
                                style: RothkoTextStyles.s2.copyWith(
                                    color: widget.disabled && widget.filled!
                                        ? RothkoColor.kDarkNeutralLighten1
                                        : widget.disabled && !widget.filled!
                                            ? RothkoColor.kDarkNeutralLighten2
                                            : widget.textColor,
                                    fontSize: widget.fontSize ?? 14,
                                    fontWeight: FontWeight.w500,
                                    fontFamily: "Graphik",
                                    height: 1,
                                    decoration: TextDecoration.none),
                              ),
                            ),
                            widget.buttonIcon != null
                                ? SizedBox(
                                    width: 9.1,
                                  )
                                : SizedBox.shrink(),
                            widget.buttonIcon ?? SizedBox.shrink()
                          ],
                        ),
                )
              : widget.size == ButtonSize.LARGE
                  ? Container(
                      alignment: Alignment.center,
                      width: widget.fullScreen! ? w : null,
                      height: widget.height ?? 48,
                      constraints: BoxConstraints(minWidth: 117),
                      decoration: BoxDecoration(
                        color: getButtonColor(
                            color: widget.color,
                            disabled: widget.disabled,
                            filled: widget.filled!,
                            hasBeenPressed: widget.hasBeenPressed!),
                        border: widget.border!
                            ? Border.all(
                                width: 1.0,
                                color: widget.disabled
                                    ? RothkoColor.kLightNeutralBase
                                    : widget.filled == true
                                        ? widget.color
                                        : widget.borderColor != null
                                            ? widget.borderColor!
                                            : widget.color,
                              )
                            : Border(),
                        borderRadius: BorderRadius.only(
                            topRight: Radius.circular(4),
                            bottomLeft: Radius.circular(4),
                            bottomRight: Radius.circular(4),
                            topLeft: Radius.circular(4)),
                      ),
                      padding: EdgeInsets.symmetric(
                          horizontal: widget.fullScreen != true ? 24 : 0,
                          vertical: 14),
                      child: widget.loading!
                          ? Container(
                              width: 20,
                              height: 20,
                              decoration: BoxDecoration(shape: BoxShape.circle),
                              child: widget.fullScreen!
                                  ? Center(
                                      widthFactor: 1,
                                      heightFactor: 1,
                                      child: CircularProgressIndicator(
                                        backgroundColor:
                                            widget.indicatorColor != null
                                                ? widget.indicatorColor!
                                                : Colors.transparent,
                                        valueColor:
                                            AlwaysStoppedAnimation<Color>(widget
                                                        .indicatorValueColor !=
                                                    null
                                                ? widget.indicatorValueColor!
                                                : Colors.white),
                                        strokeWidth: 3,
                                      ),
                                    )
                                  : CircularProgressIndicator(
                                      backgroundColor:
                                          widget.indicatorColor != null
                                              ? widget.indicatorColor!
                                              : Colors.transparent,
                                      valueColor: AlwaysStoppedAnimation<Color>(
                                          widget.indicatorValueColor != null
                                              ? widget.indicatorValueColor!
                                              : Colors.white),
                                      strokeWidth: 3,
                                    ),
                            )
                          : Row(
                              mainAxisSize: MainAxisSize.min,
                              mainAxisAlignment: widget.fullScreen!
                                  ? MainAxisAlignment.center
                                  : MainAxisAlignment.start,
                              children: widget.loading! && widget.fullScreen!
                                  ? [
                                      CircularProgressIndicator(
                                        backgroundColor:
                                            widget.indicatorColor != null
                                                ? widget.indicatorColor!
                                                : Colors.transparent,
                                        valueColor:
                                            AlwaysStoppedAnimation<Color>(widget
                                                        .indicatorValueColor !=
                                                    null
                                                ? widget.indicatorValueColor!
                                                : Colors.white),
                                        strokeWidth: 3,
                                      ),
                                    ]
                                  : [
                                      Text(
                                        widget.text!,
                                        textAlign: TextAlign.center,
                                        style: RothkoTextStyles.s1.copyWith(
                                            color: widget.disabled &&
                                                    widget.filled!
                                                ? RothkoColor
                                                    .kDarkNeutralLighten1
                                                : widget.disabled &&
                                                        !widget.filled!
                                                    ? RothkoColor
                                                        .kDarkNeutralLighten2
                                                    : widget.textColor,
                                            height: 1,
                                            fontSize: widget.fontSize ?? 16,
                                            fontWeight: FontWeight.w500,
                                            fontFamily: "Graphik",
                                            decoration: TextDecoration.none),
                                      ),
                                      widget.buttonIcon != null
                                          ? SizedBox(
                                              width: 9.1,
                                            )
                                          : SizedBox.shrink(),
                                      widget.buttonIcon ?? SizedBox.shrink()
                                    ],
                            ),
                    )
                  : Container(),
    );
  }
}

Color getButtonColor(
    {required Color color,
    required bool disabled,
    required bool filled,
    required bool hasBeenPressed}) {
  List<Color> colors = [
    RothkoColor.kPrimaryBase,
    RothkoColor.kSuccessBase,
    RothkoColor.kWarningBase,
    RothkoColor.kAccentBase
  ];
  List<Color> darkenColors = [
    RothkoColor.kPrimaryDarken1,
    RothkoColor.kSuccessDarken1,
    RothkoColor.kWarningDarken1,
    RothkoColor.kAccentDarken1
  ];
  if (filled && (!colors.contains(color))) {
    if (disabled) {
      return RothkoColor.kLightNeutralBase;
    }
    return color;
  } else if (disabled && filled) {
    return RothkoColor.kLightNeutralBase;
  } else if (disabled && !filled) {
    if (color == RothkoColor.kErrorBase) {
      return RothkoColor.kLightNeutralLighten2;
    }
    return RothkoColor.kLightNeutralLighten1;
  } else if (!disabled && filled && hasBeenPressed) {
    int index = colors.indexWhere((element) => element == color);
    if (index == -1) {
      index = 0;
    }
    return darkenColors[index];
  } else if (filled) {
    return color;
  }

  return Colors.transparent;
}
