import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko_system/buttons/button-tap.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

/// Indicates if Button size is going to be [Small],[Normal], [Large] or [Xlarge]
enum IconButtonSize {
  XSMALL,
  SMALL,
  NORMAL,
}

class RothkoIconButton extends StatefulWidget {
  Color backgroundColor;
  Color rothkoIconColor;
  bool transparent;
  double? fontSize;
  bool disabled;
  IconData? buttonIcon;
  Widget? buttonWidget;

  IconButtonSize size;
  bool? loading;
  bool? hasBeenPressed;

  void Function()? onPressed;

  RothkoIconButton(
      {this.disabled = false,
      this.transparent = false,
      this.rothkoIconColor = RothkoColor.kLightNeutralLighten2,
      this.backgroundColor = RothkoColor.kPrimaryBase,
      this.size = IconButtonSize.NORMAL,
      this.loading = false,
      this.hasBeenPressed = false,
      this.buttonWidget,
      this.buttonIcon,
      this.onPressed})
      : assert(buttonIcon != null || buttonWidget != null);
  @override
  _RothkoIconButtonState createState() => _RothkoIconButtonState();
}

class _RothkoIconButtonState extends State<RothkoIconButton>
    with SingleTickerProviderStateMixin {
  AnimationController? _animationController;
  Duration duration = const Duration(milliseconds: 80);

  @override
  void dispose() {
    _animationController!.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    double w = MediaQuery.of(context).size.width;
    return ButtonTap(
        disabled: widget.disabled,
        onTap: widget.loading! || widget.disabled
            ? () {}
            : widget.onPressed ??
                () {
                  setState(() {
                    widget.hasBeenPressed = !widget.hasBeenPressed!;
                  });
                },
        child: widget.transparent
            ? Icon(widget.buttonIcon,
                size: widget.size == IconButtonSize.SMALL
                    ? 16
                    : widget.size == IconButtonSize.XSMALL
                        ? 8
                        : 24,
                color: widget.disabled
                    ? RothkoColor.kLightNeutralDarken2
                    : widget.rothkoIconColor)
            : Container(
                decoration: BoxDecoration(
                    color: widget.disabled
                        ? RothkoColor.kLightNeutralBase
                        : widget.backgroundColor,
                    borderRadius: BorderRadius.circular(4)),
                padding: EdgeInsets.all(
                  widget.size == IconButtonSize.XSMALL ? 4 : 8,
                ),
                child: widget.buttonWidget ??
                    Icon(widget.buttonIcon,
                        size: widget.size == IconButtonSize.SMALL
                            ? 16
                            : widget.size == IconButtonSize.XSMALL
                                ? 8
                                : 24,
                        color: widget.disabled
                            ? RothkoColor.kDarkNeutralLighten2
                            : widget.rothkoIconColor),
              ));
  }
}
