import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';
import 'package:rothko_mobile/rothko_system/utilities/index.dart';
import 'package:rothko_mobile/rothko_system/utilities/textstyles.dart';

class RothkoDismissibleChip extends StatelessWidget {
  Function onDeleted;
  final String text;
  final String? leadingTitle, username, profileImageUrl;
  final double? fontSize;
  final Color? chipColor,
      avatarColor,
      initialsColor,
      labelColor,
      deleteIconColor;
  final bool? withLeadingTitle;
  final bool withvatar;
  final ImageProvider? profileDecorImgType;

  RothkoDismissibleChip(
      {this.fontSize,
      this.username,
      this.profileImageUrl,
      required this.withLeadingTitle,
      required this.withvatar,
      required this.text,
      this.leadingTitle,
      this.labelColor,
      this.profileDecorImgType,
      this.chipColor,
      this.deleteIconColor,
      this.initialsColor,
      this.avatarColor,
      required this.onDeleted});

  @override
  Widget build(BuildContext context) {
    var nameInitial;

    Widget _profileImage(String fullName, String image) {
      var names = fullName.split(' ');

      if (image.length > 0) {
        nameInitial = ' ';
      } else if (names.length > 1) {
        String firstName = names[0];
        String lastName = names[1];
        nameInitial = firstName[0].toUpperCase() + lastName[0].toUpperCase();
      } else {
        nameInitial = fullName[0].toUpperCase();
      }

      return Container(
        decoration: BoxDecoration(
          color: avatarColor,
          borderRadius: BorderRadius.circular(100.0),
        ),
        child: Center(
          child: Text(
            nameInitial,
            style: TextStyle(
              fontFamily: RothkoTextStyles.overline.fontFamily,
              color: initialsColor ?? RothkoColor.kLightNeutralLighten2,
              fontWeight: RothkoTextStyles.overline.fontWeight,
            ),
          ),
        ),
      );
    }

    return Chip(
      avatar: withvatar && !withLeadingTitle!
          ? CircleAvatar(
              child: _profileImage(username!, profileImageUrl!),
              radius: 24.0,
              backgroundColor: avatarColor,
              foregroundImage:
                  profileDecorImgType ?? AssetImage(profileImageUrl!),
            )
          : null,
      onDeleted: () => onDeleted,
      padding: EdgeInsets.zero,
      labelPadding: EdgeInsets.symmetric(horizontal: 8, vertical: 2),
      label: Text(
        withLeadingTitle! && !withvatar
            ? '${leadingTitle!}: '.toUpperCase() + text
            : text,
        style: TextStyle(
            color: labelColor,
            fontFamily: RothkoTextStyles.caption.fontFamily,
            fontWeight: RothkoTextStyles.caption.fontWeight),
      ),
      backgroundColor: chipColor ??
          (RothkoCache.getTheme!(context) == ThemeMode.light
              ? RothkoColor.kDarkNeutralbase
              : RothkoColor.kLightNeutralBase),
      deleteIcon: Icon(
        Icons.cancel_rounded,
      ),
      deleteIconColor: deleteIconColor ??
          (RothkoCache.getTheme!(context) == ThemeMode.light
              ? RothkoColor.kDarkNeutralbase
              : RothkoColor.kLightNeutralLighten2),
    );
  }
}
