import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

//Future<void> ShowDialogIcon(BuildContext context) async {
//  showDialog(
//      context: context,
//      barrierDismissible: true,
//      builder: (BuildContext context) {
//        return DialogWithIcon();
//      });
//}

class DefaultDialog extends StatelessWidget {
  final String? message, header, buttonText;
  final Color? messageColor,
      buttonColor,
      bannerColor,
      iconColor,
      buttonTextColor;
  final bool? withCancelButton;
  final RothkoButton? button;

  final Function()? onTapAction, onCancel, onCloseModal;
  final IconData? dialogIcon;
  final double? width, msgFontSize, buttonWidth;

  DefaultDialog(
      {this.message,
      this.onCloseModal,
      this.messageColor,
      this.header,
      this.onCancel,
      this.button,
      this.withCancelButton = true,
      this.buttonText,
      this.dialogIcon,
      this.iconColor,
      this.buttonColor,
      this.bannerColor,
      this.buttonTextColor,
      this.onTapAction,
      this.width,
      this.buttonWidth,
      this.msgFontSize});
  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      insetPadding: EdgeInsets.zero,
      contentPadding: EdgeInsets.zero,
      clipBehavior: Clip.antiAliasWithSaveLayer,
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(8.0),
      ),
      backgroundColor: kLightNeutralLighten0,
      content: Container(
        height: 350.0,
        decoration: BoxDecoration(
          color: RothkoColor.kLightNeutralLighten1,
          borderRadius: BorderRadius.circular(4.0),
        ),
        width: MediaQuery.of(context).size.width * 0.9,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            Padding(
              padding: const EdgeInsets.all(16.0),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Text(
                    header ?? 'Header',
                    style: TextStyle(
                        color: kDarkNeutralBase,
                        fontWeight: FontWeight.w700,
                        fontSize: 20.0,
                        fontFamily: 'Proxima Nova'),
                  ),
                  IconButton(
                      onPressed: onCloseModal ?? () => Navigator.pop(context),
                      padding: EdgeInsets.zero,
                      icon: Icon(
                        Icons.close,
                        size: 16.0,
                        color: kDarkNeutralLighten5,
                      )),
                ],
              ),
            ),
            Column(
              children: [
                Padding(
                  padding: const EdgeInsets.symmetric(horizontal: 16.0),
                  child: Container(
                    padding: EdgeInsets.all(16),
                    height: 160.0,
                    width: MediaQuery.of(context).size.width,
                    decoration: BoxDecoration(
                      color: bannerColor ?? kPrimaryLighten5,
                    ),
                    child: Text(
                      message ??
                          'Your request to enable Bento wallet has been received.'
                              '\nA confirmation email has been sent to you.',
                      style: TextStyle(
                          fontWeight: FontWeight.w600,
                          color: messageColor ?? kPrimaryDarken4,
                          fontSize: msgFontSize ?? 14,
                          height: 1.5,
                          fontFamily: 'Proxima Nova'),
                    ),
                  ),
                ),
                SizedBox(
                  height: 24.0,
                ),
                Container(
                  height: 64.0,
                  decoration: BoxDecoration(
                      color: RothkoColor.kLightNeutralDarken1,
                      borderRadius: BorderRadius.only(
                          bottomLeft: Radius.circular(8),
                          bottomRight: Radius.circular(8))),
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.end,
                    children: [
                      withCancelButton!
                          ? Container(
                              padding: EdgeInsets.all(8.0),
                              width: 80.0,
                              height: 32.0,
                              child: GestureDetector(
                                onTap: onCancel,
                                child: Text(
                                  'Cancel',
                                  style: TextStyle(
                                      fontWeight: FontWeight.w600,
                                      color: kDarkNeutralBase,
                                      fontSize: 14.0),
                                ),
                              ),
                            )
                          : Container(),
                      button ??
                          RothkoButton(
                            loading: false,
                            size: ButtonSize.NORMAL,
                            text: "Accept",
                            onPressed: onTapAction,
                            filled: false,
                          ),
                    ],
                  ),
                )
              ],
            ),
          ],
        ),
      ),
    );
  }
}
