import 'package:date_format/date_format.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:rothko_mobile/rothko.dart';
import 'package:rothko_mobile/rothko_system/utilities/textstyles.dart';

enum DisplaySize { SMALL, LARGE }

class RothkoDisplayStates extends StatefulWidget {
  final String heading;
  final String? displayImage;
  final Color bgColor;
  final String subheading;
  final bool isErrorDisplay;
  final Function()? primaryCallback;
  final String? primaryBtnText;
  final Color primaryBtnTextColor;
  final Color primaryBtnColor;
  final Color? primaryBtnBorderColor;
  final DisplaySize size;
  final bool primaryLoading;
  final Function()? secondaryCallback;
  final String? secondaryBtnText;
  final Color secondaryBtnTextColor;
  final Color secondaryBtnColor;
  final Color? secondaryBorderColor;
  final bool secondayLoading;
  final double? height;
  final bool singleCTA;
  const RothkoDisplayStates({
    Key? key,
    required this.heading,
    this.displayImage,
    this.singleCTA = false,
    this.bgColor = RothkoColor.kLightNeutralLighten2,
    required this.subheading,
    required this.isErrorDisplay,
    this.primaryCallback,
    this.size = DisplaySize.SMALL,
    required this.primaryBtnText,
    this.primaryLoading = false,
    this.secondaryCallback,
    this.height,
    required this.secondaryBtnText,
    this.secondayLoading = false,
    this.primaryBtnTextColor = RothkoColor.kPrimaryBase,
    this.primaryBtnColor = RothkoColor.kLightNeutralLighten2,
    this.primaryBtnBorderColor = RothkoColor.kLightNeutralBase,
    this.secondaryBtnTextColor = RothkoColor.kLightNeutralLighten2,
    this.secondaryBtnColor = RothkoColor.kPrimaryBase,
    this.secondaryBorderColor,
  }) : super(key: key);

  @override
  State<RothkoDisplayStates> createState() => _RothkoDisplayStatesState();
}

class _RothkoDisplayStatesState extends State<RothkoDisplayStates> {
  bool isSvg = false;
  bool isNetWorkFile = false;

  @override
  Widget build(BuildContext context) {
    if (widget.displayImage != null) {
      isNetWorkFile = widget.displayImage!.contains("https://") ||
          widget.displayImage!.contains("http://");
      isSvg = widget.displayImage!.contains(".svg");
    }
    return Container(
      height: widget.size == DisplaySize.SMALL
          ? widget.height ?? 276
          : widget.height ?? 300,
      color: widget.bgColor,
      padding: EdgeInsets.symmetric(vertical: 40, horizontal: 24),
      child: Column(
        children: [
          if (widget.displayImage != null)
            SizedBox(
              child: isNetWorkFile
                  ? isSvg
                      ? SvgPicture.network(widget.displayImage!)
                      : Image.network(widget.displayImage!)
                  : SvgPicture.asset(widget.displayImage!),
            )
          else
            Container(
              height: 64,
              width: 64,
              decoration: BoxDecoration(
                  color: RothkoColor.kLightNeutralBase,
                  borderRadius: BorderRadius.circular(8)),
            ),
          SizedBox(
            height: widget.size == DisplaySize.SMALL ? 16 : 24,
          ),
          Text(
            widget.heading,
            style: widget.size == DisplaySize.SMALL
                ? TextStyle(
                    fontFamily: 'Graphik',
                    fontWeight: FontWeight.w500,
                    fontSize: 16,
                    color: RothkoColor.kDarkNeutralDarken2,
                  )
                : RothkoTextStyles.h3.copyWith(
                    color: RothkoColor.kDarkNeutralDarken2,
                  ),
          ),
          SizedBox(
            height: widget.size == DisplaySize.SMALL ? 4 : 8,
          ),
          Text(
            widget.subheading,
            style: RothkoTextStyles.bodyText2.copyWith(
              color: RothkoColor.kDarkNeutralbase,
            ),
            textAlign: TextAlign.center,
          ),
          SizedBox(
            height: widget.size == DisplaySize.SMALL ? 16 : 24,
          ),
          if (widget.singleCTA)
            Expanded(
              child: RothkoButton(
                filled: true,
                borderColor: widget.secondaryBorderColor,
                text: widget.secondaryBtnText,
                color: widget.secondaryBtnColor,
                loading: widget.secondayLoading,
                onPressed: widget.secondaryCallback,
              ),
            )
          else
            Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Expanded(
                  child: RothkoButton(
                    text: widget.primaryBtnText,
                    loading: widget.primaryLoading,
                    color: widget.primaryBtnColor,
                    borderColor: widget.primaryBtnBorderColor,
                    textColor: widget.primaryBtnTextColor,
                    onPressed: widget.primaryCallback,
                  ),
                ),
                SizedBox(
                  width: widget.size == DisplaySize.SMALL ? 8 : 12,
                ),
                Expanded(
                  child: RothkoButton(
                    filled: true,
                    borderColor: widget.secondaryBorderColor,
                    text: widget.secondaryBtnText,
                    color: widget.secondaryBtnColor,
                    textColor:widget.secondaryBtnTextColor,
                    loading: widget.secondayLoading,
                    onPressed: widget.secondaryCallback,
                  ),
                ),
              ],
            )
        ],
      ),
    );
  }
}
