import 'package:flutter/material.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class RothkoSearchBox extends StatefulWidget {
  final String? label, hint;

  bool? readOnly, enabled;

  final TextEditingController? textCtrl;
  final double? width;

  RothkoSearchBox({
    @required this.label,
    @required this.readOnly,
    @required this.enabled,
    this.textCtrl,
    this.hint,
    this.width,
  });
  TextEditingController _textfieldController = TextEditingController();
  @override
  _RothkoSearchBoxState createState() => _RothkoSearchBoxState();
}

class _RothkoSearchBoxState extends State<RothkoSearchBox> {
  FocusNode? _labelFocusNode;
  Color fillColor = kLightNeutralLighten5;

  @override
  void initState() {
    super.initState();
    _labelFocusNode = FocusNode();
  }

  @override
  void dispose() {
    _labelFocusNode!.dispose();
    super.dispose();
  }

  void _requestFocus() {
    setState(() {
      FocusScope.of(context).requestFocus(_labelFocusNode);
    });
  }

  @override
  Widget build(BuildContext context) {
    return Ink(
      child: InkWell(
        child: Container(
          width: widget.width ?? 320.0,
          height: 50.0,
          child: TextFormField(
            maxLengthEnforced: false,
            enabled: widget.enabled,
            readOnly: widget.readOnly!,
            controller: widget.textCtrl ?? widget._textfieldController,
            cursorColor: RothkoCache.getTheme!(context) == ThemeMode.light
                ? RothkoColor.kDarkNeutralbase
                : RothkoColor.kLightNeutralBase,
            // cursorHeight: 24.0,
            focusNode: _labelFocusNode,
            onTap: _requestFocus,
            style: TextStyle(
                color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                        widget.enabled!
                    ? kDarkNeutralBase
                    : RothkoCache.getTheme!(context) == ThemeMode.light &&
                            !widget.enabled!
                        ? kDarkNeutralLighten4
                        : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                !widget.enabled!
                            ? kPrimaryLighten3
                            : kLightNeutralBase,
                fontFamily: 'Graphik',
                fontSize: 16.0,
                fontWeight: FontWeight.w400),
            decoration: InputDecoration(
              errorStyle: TextStyle(color: kErrorBase),
              errorBorder:
                  OutlineInputBorder(borderSide: BorderSide(color: kErrorBase)),
              focusedBorder: OutlineInputBorder(
                  borderSide: BorderSide(
                      color: RothkoCache.getTheme!(context) == ThemeMode.light
                          ? RothkoColor.kPrimaryBase
                          : kDarkNeutralLighten2)),
              fillColor: RothkoCache.getTheme!(context) == ThemeMode.light &&
                      !_labelFocusNode!.hasFocus
                  ? RothkoColor.kLightNeutralLighten2
                  : RothkoCache.getTheme!(context) == ThemeMode.light &&
                          _labelFocusNode!.hasFocus &&
                          widget.enabled!
                      ? RothkoColor.kLightNeutralLighten2
                      : RothkoCache.getTheme!(context) == ThemeMode.light &&
                              !_labelFocusNode!.hasFocus
                          ? kDarkNeutralBase
                          : kDarkNeutralLighten1,
              filled: true,
              hintText: widget.hint,
              helperStyle: TextStyle(
                  fontSize: 10.0,
                  color: kDarkNeutralLighten3,
                  fontFamily: 'Graphik'),
              prefixIcon: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  SizedBox(
                    height: 16,
                    width: 16,
                    child: Image.asset(
                      'assets/img/search.png',
                      color: RothkoColor.kPrimaryBase,
                    ),
                  ),
                ],
              ),
              contentPadding: EdgeInsets.only(top: 10),
              hintStyle: TextStyle(
                  fontSize: 16.0,
                  fontFamily: 'Graphik',
                  color: RothkoCache.getTheme!(context) == ThemeMode.light &&
                          !_labelFocusNode!.hasFocus &&
                          widget.enabled!
                      ? RothkoColor.kDarkNeutralLighten1
                      : RothkoCache.getTheme!(context) == ThemeMode.light &&
                              _labelFocusNode!.hasFocus &&
                              widget.enabled!
                          ? RothkoColor.kDarkNeutralDarken2
                          : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                  !_labelFocusNode!.hasFocus &&
                                  widget.enabled!
                              ? kLightNeutralBase
                              : kPrimaryLighten3),
              enabledBorder: OutlineInputBorder(
                  borderSide: BorderSide(
                      color: RothkoCache.getTheme!(context) == ThemeMode.light
                          ? RothkoColor.kLightNeutralDarken1
                          : kDarkNeutralLighten2)),
              border: OutlineInputBorder(
                  borderSide: BorderSide(
                      color: RothkoCache.getTheme!(context) == ThemeMode.light
                          ? kLightNeutralLighten1
                          : kDarkNeutralLighten2)),
            ),
          ),
        ),
        onTap: () {
          setState(() {
            fillColor = RothkoCache.getTheme!(context) == ThemeMode.light
                ? kLightNeutralLighten4
                : kLightNeutralLighten1;
          });
        },
      ),
    );
  }
}
