import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko.dart';
import 'package:rothko_mobile/rothko_system/tooltip/rothko_tooltip.dart';
import 'package:rothko_mobile/rothko_system/tooltip/withTitle.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';
import 'package:rothko_mobile/rothko_system/utilities/textstyles.dart';

enum DropDownSize { Small, Normal }
// size of our dropdown

class SelectDefaultDynamic<T> extends StatefulWidget {
  final List<T> options;
  final BuildContext? context;
  final void Function(T?)? onChanged;
  DropDownSize? size;
  final T? selected;
  final String hintText;
  final Widget suffixIcon;
  final bool? networkIcons;
  final bool hasIcons;
  final bool showTooltip;
  final String? toolTipText;
  final bool inlineLabel;
  final bool hasAvatarIcons;
  final String labelText;
  final Color? labelTextColor;
  final AvatarSize avatarSize;
  final Color avatarColor;
  final String? Function(T?)? validator;
  final String Function(T?) getText;
  final String Function(T?)? getIcons;
  final AutovalidateMode? autovalidateMode;
  bool? enabled;
  Function()? onTap;
  final Widget labelAction;
  Function()? tooltipAction;
  bool? readonly;
  final double? labelTextSize, width;
  bool? focused;
  final BorderSide? customBorder;

  SelectDefaultDynamic(
      {required this.options,
      required this.getText,
      this.context,
      this.size,
      this.getIcons,
      this.inlineLabel = false,
      this.avatarColor = RothkoColor.kPrimaryBase,
      this.hasIcons = false,
      this.avatarSize = AvatarSize.normal,
      this.hasAvatarIcons = false,
      this.networkIcons = false,
      this.onChanged,
      this.autovalidateMode,
      this.labelAction = const SizedBox(),
      this.selected,
      required this.hintText,
      this.focused = false,
      this.readonly = false,
      this.onTap,
      this.enabled = true,
      this.showTooltip = false,
      this.toolTipText = '',
      this.tooltipAction,
      this.suffixIcon = const Icon(
        Icons.arrow_drop_down_rounded,
      ),
      required this.labelText,
      this.labelTextColor,
      this.validator,
      this.labelTextSize,
      this.customBorder,
      this.width});
  // : assert(hasIcons! ? getIcons != null : true);
  @override
  _SelectDefaultDynamicState createState() => _SelectDefaultDynamicState<T>();
}

class _SelectDefaultDynamicState<T> extends State<SelectDefaultDynamic> {
  FocusNode? _labelFocusNode;
  Color fillColor = kLightNeutralLighten5;

  void _requestFocus() {
    setState(() {
      FocusScope.of(context).requestFocus(_labelFocusNode);
    });
  }

  bool isFocused = false;
  @override
  void initState() {
    super.initState();
    _labelFocusNode = FocusNode();
    requestFocus();
  }

  @override
  void dispose() {
    _labelFocusNode!.dispose();
    super.dispose();
  }

  void requestFocus() {
    if (widget.selected != null) {
      setState(() {
        isFocused = true;
        widget.focused = true;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width * 0.9,
      padding: EdgeInsets.zero,
      child: Stack(
        children: [
          Column(
            children: [
              if (!widget.inlineLabel) ...[
                Row(
                  children: [
                    Text(
                      widget.labelText,
                      style: RothkoTextStyles.caption.copyWith(
                          fontWeight: FontWeight.w500,
                          color:
                              RothkoCache.getTheme!(context) == ThemeMode.light
                                  ? RothkoColor.kDarkNeutralDarken2
                                  : RothkoColor.kLightNeutralDarken1,
                          letterSpacing: .05),
                    ),
                    SizedBox(
                      width: 5.1,
                    ),
                    if (widget.showTooltip)
                      RothkoTooltipWithTitle(
                          title: widget.toolTipText ?? 'This is the title',
                          message: 'This is the message for the tooltip',
                          triggerWidget: Icon(
                            Icons.info,
                            color: RothkoColor.kPrimaryBase,
                            size: 20,
                          ),
                          direction: AxisDirection.up,
                          toolTipHeight: 120.0),
                    Spacer(),
                    widget.labelAction
                  ],
                ),
                SizedBox(
                  height: 8,
                )
              ],
              SizedBox(
                child: DropdownButtonFormField<T>(
                  isDense: true,
                  autovalidateMode: widget.autovalidateMode,
                  validator: (val) {
                    return widget.validator?.call(val);
                  },
                  isExpanded: true,
                  items: widget.options.map<DropdownMenuItem<T>>((f) {
                    return DropdownMenuItem<T>(
                      onTap: widget.onTap,
                      child: widget.hasIcons && !widget.hasAvatarIcons
                          ? Row(
                              children: [
                                if (widget.inlineLabel) ...[
                                  Text(widget.labelText,
                                      style:
                                          RothkoTextStyles.bodyText1.copyWith(
                                        color: RothkoColor.kDarkNeutralbase,
                                      )),
                                  SizedBox(width: 8)
                                ],
                                widget.networkIcons!
                                    ? SizedBox(
                                        height: 30,
                                        width: 30,
                                        child:
                                            widget.getIcons!(f).contains('svg')
                                                ? SvgPicture.network(
                                                    '${widget.getIcons!(f)}')
                                                : Image.network(
                                                    '${widget.getIcons!(f)}'))
                                    : SizedBox(
                                        height: 30,
                                        width: 30,
                                        child:
                                            widget.getIcons!(f).contains('svg')
                                                ? SvgPicture.asset(
                                                    '${widget.getIcons!(f)}')
                                                : Image.asset(
                                                    '${widget.getIcons!(f)}')),
                                SizedBox(width: 8),
                                Text(
                                  //new update
                                  '${widget.getText(f)}',
                                  style: RothkoTextStyles.bodyText1.copyWith(
                                      overflow: TextOverflow.ellipsis,
                                      color: widget.enabled! &&
                                              RothkoCache.getTheme!(context) ==
                                                  ThemeMode.light
                                          ? RothkoColor.kDarkNeutralDarken2
                                          : !widget.enabled! &&
                                                  RothkoCache
                                                          .getTheme!(context) ==
                                                      ThemeMode.light
                                              ? kDarkNeutralLighten3
                                              : kLightNeutralLighten5,
                                      fontSize: widget.labelTextSize ?? 16),
                                ),
                              ],
                            )
                          : widget.hasAvatarIcons
                              ? Row(
                                  children: [
                                    if (widget.inlineLabel) ...[
                                      Text(widget.labelText,
                                          style: RothkoTextStyles.bodyText1
                                              .copyWith(
                                            color: RothkoColor.kDarkNeutralbase,
                                          )),
                                      SizedBox(width: 8)
                                    ],
                                    RothkoAvatar(
                                      color: kPrimaryBase,
                                      size: AvatarSize.normal,
                                      name:
                                          '${widget.getText(f)[0]} ${widget.getText(f)[1]}',
                                    ),
                                    SizedBox(width: 8),
                                    Text(
                                      '${widget.getText(f)}',
                                      style: RothkoTextStyles.bodyText1
                                          .copyWith(
                                            fontWeight:FontWeight.w500,
 fontSize:
                                                  widget.labelTextSize ?? 14,
                                              overflow: TextOverflow.ellipsis,
                                              color: widget.enabled! &&
                                                      RothkoCache.getTheme!(
                                                              context) ==
                                                          ThemeMode.light
                                                  ? RothkoColor
                                                      .kDarkNeutralDarken2
                                                  : !widget.enabled! &&
                                                          RothkoCache.getTheme!(
                                                                  context) ==
                                                              ThemeMode.light
                                                      ? kDarkNeutralLighten3
                                                      : kLightNeutralLighten5,
                                             ),
                                    ),
                                  ],
                                )
                              : Row(
                                  children: [
                                    if (widget.inlineLabel) ...[
                                      Text(widget.labelText,
                                          style: RothkoTextStyles.bodyText1
                                              .copyWith(
                                            color: RothkoColor.kDarkNeutralbase,
                                          )),
                                      SizedBox(width: 8)
                                    ],
                                    Text(
                                      '${widget.getText(f)}',
                                      style: RothkoTextStyles.bodyText1
                                          .copyWith(
                                              overflow: TextOverflow.ellipsis,
                                              color: widget.enabled! &&
                                                      RothkoCache.getTheme!(
                                                              context) ==
                                                          ThemeMode.light
                                                  ? RothkoColor
                                                      .kDarkNeutralDarken2
                                                  : !widget.enabled! &&
                                                          RothkoCache.getTheme!(
                                                                  context) ==
                                                              ThemeMode.light
                                                      ? kDarkNeutralLighten3
                                                      : kLightNeutralLighten5,
                                              fontSize:
                                                  widget.labelTextSize ?? 16),
                                    ),
                                  ],
                                ),
                      value: f,
                    );
                  }).toList(),
                  onChanged: widget.enabled! && widget.readonly == false
                      ? (x) {
                          widget.onChanged?.call(x);
                        }
                      : null,
                  value: widget.selected,
                  onTap: () {
                    setState(() {
                      isFocused = true;
                      widget.focused = true;
                    });
                  },
                  decoration: InputDecoration(
                    hintText: widget.inlineLabel
                        ? widget.labelText + '  ' + widget.hintText
                        : widget.hintText,
                    suffixIconConstraints: widget.size == DropDownSize.Small
                        ? BoxConstraints(maxHeight: 10)
                        : BoxConstraints(minHeight: 12.0),
                    enabled: widget.enabled!,
                    border: OutlineInputBorder(
                        borderRadius: BorderRadius.circular(8),
                        borderSide: widget.customBorder ??
                            BorderSide(
                                color: RothkoCache.getTheme!(context) ==
                                        ThemeMode.light
                                    ? RothkoColor.kLightNeutralDarken1
                                    : RothkoColor.kDarkNeutralDarken1)),
                    errorStyle: TextStyle(color: kErrorBase),
                    errorBorder: OutlineInputBorder(
                        borderRadius: BorderRadius.circular(8),
                        borderSide: BorderSide(color: kErrorBase)),
                    enabledBorder: OutlineInputBorder(
                        borderRadius: BorderRadius.circular(8),
                        borderSide: widget.customBorder ??
                            BorderSide(
                                style: BorderStyle.solid,
                                color: RothkoCache.getTheme!(context) ==
                                        ThemeMode.light
                                    ? kLightNeutralLighten1
                                    : kLightNeutralLighten5)),
                    focusedBorder: OutlineInputBorder(
                        borderRadius: BorderRadius.circular(8),
                        borderSide: widget.customBorder ??
                            BorderSide(
                                style: BorderStyle.solid,
                                color: RothkoCache.getTheme!(context) ==
                                        ThemeMode.light
                                    ? kLightNeutralLighten1
                                    : Colors.red)),
                    contentPadding: const EdgeInsets.symmetric(
                        vertical: 8.0, horizontal: 12.0),
                    hintStyle: TextStyle(
                        color:
                            RothkoCache.getTheme!(context) == ThemeMode.light &&
                                    !_labelFocusNode!.hasFocus &&
                                    widget.enabled!
                                ? kDarkNeutralLighten3
                                : RothkoCache.getTheme!(context) ==
                                            ThemeMode.light &&
                                        _labelFocusNode!.hasFocus &&
                                        widget.enabled!
                                    ? kDarkNeutralLighten3
                                    : RothkoCache.getTheme!(context) ==
                                                ThemeMode.dark &&
                                            !_labelFocusNode!.hasFocus &&
                                            widget.enabled!
                                        ? kLightNeutralBase
                                        : kPrimaryLighten3,
                        fontFamily: 'Proxima Nova',
                        fontSize: 16,
                        fontWeight: FontWeight.w400),
                    labelStyle: RothkoTextStyles.caption.copyWith(
                        fontWeight: FontWeight.w500,
                        color: RothkoCache.getTheme!(context) == ThemeMode.light
                            ? RothkoColor.kDarkNeutralDarken2
                            : RothkoColor.kLightNeutralDarken1,
                        letterSpacing: .05),
                  ),
                  icon: widget.suffixIcon,
                ),
              ),
            ],
          ),
          // Positioned(
          //     left: 13,
          //     top: isFocused
          //         ? 7
          //         : isFocused && widget.hasIcons
          //             ? 4
          //             : 18,
          //     child: Text(
          //       widget.size == DropDownSize.Small && isFocused
          //           ? ''
          //           : widget.labelText!,
          //       style: TextStyle(
          //           fontSize: isFocused ? 10 : 14,
          //           fontFamily: 'Proxima Nova',
          //           color: RothkoCache.getTheme!(context) == ThemeMode.light &&
          //                   !_labelFocusNode!.hasFocus &&
          //                   widget.enabled!
          //               ? kDarkNeutralLighten3
          //               : RothkoCache.getTheme!(context) == ThemeMode.light &&
          //                       _labelFocusNode!.hasFocus &&
          //                       widget.enabled!
          //                   ? kDarkNeutralLighten3
          //                   : RothkoCache.getTheme!(context) ==
          //                               ThemeMode.dark &&
          //                           !_labelFocusNode!.hasFocus &&
          //                           widget.enabled!
          //                       ? kLightNeutralBase
          //                       : kPrimaryLighten3),
          //     ))
        ],
      ),
    );
  }
}
