import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';

class Paper extends StatelessWidget {
  final double? spreadRadius,
      borderRadius,
      blurRadius,
      thickness,
      height,
      width;
  final Color? color, shadowColor, borderColor;
  final bool? hasElevation;
  final Widget? child;
  final bool filled;

  Paper({
    this.spreadRadius,
    this.color,
    this.borderRadius,
    this.shadowColor,
    this.blurRadius,
    this.hasElevation,
    this.child,
    required this.filled,
    this.borderColor,
    this.thickness,
    this.height,
    this.width,
  });
  @override
  Widget build(BuildContext context) {
    return Material(
      shadowColor: shadowColor,
      elevation: hasElevation! ? 10.0 : 0.0,
      borderRadius: BorderRadius.circular(borderRadius!),
      child: Container(
        height: height ?? MediaQuery.of(context).size.height * 0.9,
        width: width ?? MediaQuery.of(context).size.width * 0.9,
        decoration: BoxDecoration(
            border: Border.all(
              width: (hasElevation! || filled) ? 0 : thickness ?? 0,
              color: (hasElevation! || filled)
                  ? Colors.transparent
                  : borderColor ?? RothkoColor.kLightNeutralLighten2,
            ),
            color: color,
            borderRadius: BorderRadius.circular(borderRadius!),
            boxShadow: (hasElevation == true && !filled)
                ? [
                    BoxShadow(
                      color: shadowColor!,
                      offset: Offset(0, 50),
                      blurRadius: blurRadius!,
                      spreadRadius: -(spreadRadius!),
                    )
                  ]
                : null),
        child: child,
      ),
    );
  }
}
