import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/tooltip/withAction.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';
import 'package:rothko_mobile/rothko_system/utilities/textstyles.dart';

class RothkoTextFieldDefault extends StatefulWidget {
  final String? label, helperHint;

  Widget? suffixWidget;
  Widget? suffixIcon;
  Widget? prefixWidget;
  bool? readOnly, enabled, hasCounter;
  bool obscure;
  final Key? key;
  ValueChanged<String>? onChanged;
  TextInputType? keyboardType;
  AutovalidateMode? autovalidateMode;
  bool enableSuggestions;
  String? hintText;
  String? Function(String?)? validator;
  List<TextInputFormatter>? inputFormatters;
  final int? maxlength;
  final int? maxLines;
  final String? initialValue;
  final TextEditingController? textCtrl;
  final Widget? labelWidget;

  TextCapitalization? textCapitalization;

  final VoidCallback? toolTipAction;
  final String? toolTipText;
  final bool showToolTip;

  RothkoTextFieldDefault({
    @required this.label,
    this.suffixWidget,
    this.suffixIcon,
    this.hintText,
    this.obscure = false,
    this.prefixWidget,
    @required this.readOnly,
    @required this.enabled,
    this.helperHint,
    this.toolTipAction,
    this.showToolTip = false,
    this.initialValue,
    this.autovalidateMode = AutovalidateMode.onUserInteraction,
    this.maxLines = 1,
    this.onChanged,
    this.hasCounter = false,
    this.key,
    this.inputFormatters,
    this.maxlength,
    this.keyboardType,
    this.validator,
    this.toolTipText,
    this.enableSuggestions = false,
    this.textCapitalization,
    this.textCtrl,
    this.labelWidget,
  });
  @override
  _RothkoTextFieldDefaultState createState() => _RothkoTextFieldDefaultState();
}

class _RothkoTextFieldDefaultState extends State<RothkoTextFieldDefault> {
  int textCounter = 0;
  bool notValidated = false;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width * 0.9,
      child: Column(
        children: [
          if(widget.label != null)...[
   Row(
            children: [
              widget.labelWidget ??
                  Text(
                    widget.label!,
                    style: RothkoTextStyles.caption,
                  ),
              if (widget.showToolTip) ...[
                SizedBox(
                  width: 4,
                ),
                //imported from tooltipcomponent
                RothkoTooltipWithAction(
                    onDismiss: () {},
                    title: 'Textfield',
                    message: widget.toolTipText ?? '',
                    stepperLength: 2,
                    stepperPosition: 1,
                    toolTipInfo: [],
                    primaryBtnOnTap: widget.toolTipAction ?? () {},
                    triggerWidget: Icon(
                      Icons.info,
                      size: 20,
                      color: RothkoColor.kPrimaryBase,
                    ),
                    direction: AxisDirection.up,
                    toolTipHeight: 200.0),
              ]
            ],
          ),
          ],
         
       
          SizedBox(
            height: 8,
          ),
          TextFormField(
            key: widget.key,
            initialValue: widget.initialValue,
            textCapitalization:
                widget.textCapitalization ?? TextCapitalization.none,
            enableSuggestions: widget.enableSuggestions,
            inputFormatters: widget.inputFormatters,
            keyboardType: widget.keyboardType,
            onChanged: (val) {
              if (widget.onChanged != null) {
                widget.onChanged!(val);
              }
              textCounter = val.length;

              setState(() {});
            },
            validator: (val) {
              if (widget.validator != null) {
                String? value = widget.validator!(val);

                if (value != null) {
                  notValidated = true;
                  return value;
                } else {
                  notValidated = false;
                }
              }
              // return widget.validator?.call(val);
            },
            autovalidateMode: widget.autovalidateMode,
            maxLines: widget.maxLines,
            minLines: 1,
            obscureText: widget.obscure,
            obscuringCharacter: '*',
            enabled: widget.enabled,
            readOnly: widget.readOnly!,
            controller: widget.textCtrl,
            cursorColor: RothkoCache.getTheme!(context) == ThemeMode.light
                ? RothkoColor.kDarkNeutralbase
                : RothkoColor.kLightNeutralBase,
            // cursorHeight: 20.0,
            style: RothkoTextStyles.bodyText1,
            decoration: InputDecoration(
              filled: true,
              hintText: widget.hintText,
              hintStyle: RothkoTextStyles.bodyText1
                  .copyWith(color: RothkoColor.kLightNeutralDarken2),
              fillColor: widget.enabled!
                  ? RothkoColor.kLightNeutralLighten2
                  : RothkoColor.kLightNeutralBase,
              prefixIcon: widget.prefixWidget,
              contentPadding:
                  EdgeInsets.symmetric(horizontal: 12.0, vertical: 12.0),
              isDense: true,
              errorStyle: TextStyle(color: RothkoColor.kErrorBase),
              errorBorder: OutlineInputBorder(
                  borderRadius: BorderRadius.circular(4),
                  borderSide: BorderSide(color: RothkoColor.kErrorBase)),
              focusedBorder: OutlineInputBorder(
                borderRadius: BorderRadius.circular(4),
                borderSide: BorderSide(color: RothkoColor.kPrimaryBase),
              ),
              helperText: widget.helperHint,
              alignLabelWithHint: true,
              helperStyle: TextStyle(
                  fontSize: 12.0,
                  fontWeight: FontWeight.w400,
                  color: widget.enabled!
                      ? RothkoColor.kDarkNeutralbase
                      : widget.enabled! && notValidated
                          ? RothkoColor.kErrorBase
                          : RothkoColor.kDarkNeutralLighten1,
                  fontFamily: 'Graphik'),
              suffix: widget.hasCounter!
                  ? (widget.maxlength != null && widget.enabled != false)
                      ? Text("$textCounter/${widget.maxlength}",
                          style: RothkoTextStyles.caption.copyWith(
                            fontWeight: FontWeight.w400,
                            color: notValidated
                                ? RothkoColor.kErrorBase
                                : RothkoCache.getTheme!(context) ==
                                        ThemeMode.light
                                    ? RothkoColor.kDarkNeutralbase
                                    : RothkoColor.kLightNeutralDarken2,
                          ))
                      : SizedBox()
                  : widget.suffixWidget,
              suffixIcon: widget.suffixIcon,
              enabledBorder: OutlineInputBorder(
                  borderRadius: BorderRadius.circular(4),
                  borderSide:
                      BorderSide(color: RothkoColor.kLightNeutralDarken1)),
              disabledBorder: OutlineInputBorder(
                borderRadius: BorderRadius.circular(4),
                borderSide: BorderSide(
                  color: RothkoColor.kLightNeutralDarken2,
                ),
              ),
              border: OutlineInputBorder(
                  borderRadius: BorderRadius.circular(4),
                  borderSide:
                      BorderSide(color: RothkoColor.kLightNeutralDarken1)),
            ),
          ),
        ],
      ),
    );
  }
}
