import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter/services.dart';
import 'package:rothko_mobile/cache.dart';
import 'package:rothko_mobile/rothko_system/tooltip/withAction.dart';
import 'package:rothko_mobile/rothko_system/tooltip/withTitle.dart';
import 'package:rothko_mobile/rothko_system/utilities/colors.dart';
import 'package:rothko_mobile/rothko_system/utilities/textstyles.dart';

class RothkoTextfield extends StatefulWidget {
  final String? helperHint, hintText;
  IconData? suffixIcon;
  bool? readOnly, enabled;
  final int? maxlength, maxlines;
  ValueChanged<String>? onChanged;
  TextInputType? keyboardType;
  bool enableSuggestions;
  List<TextInputFormatter>? inputFormatters;
  final TextEditingController? textCtrl;
  final String? initialValue;

  final String? Function(String?)? validator;
  final VoidCallback? toolTipAction;
  final TextStyle? hintStyle;
  final Widget? labelWidget;
  final String? toolTipText;
  final String labelText;
  final bool showSuffixIcon;
  final double height;
  final double radius;

  RothkoTextfield({
    this.suffixIcon,
    @required this.readOnly,
    this.enabled,
    this.helperHint,
    this.onChanged,
    this.inputFormatters,
    this.maxlength,
    this.keyboardType,
    this.validator,
    this.enableSuggestions = false,
    this.initialValue,
    this.maxlines,
    this.textCtrl,
    this.toolTipAction,
    this.hintText,
    this.hintStyle,
    this.labelWidget,
    this.toolTipText,
    required this.labelText,
    this.showSuffixIcon = false,
    this.height = 80,
    this.radius = 8,
  });
  @override
  _RothkoTextfieldState createState() => _RothkoTextfieldState();
}

class _RothkoTextfieldState extends State<RothkoTextfield> {
  FocusNode? _labelFocusNode;
  Color fillColor = kLightNeutralLighten5;
  TextEditingController _textfieldController = TextEditingController();
  var currentValue = '';
  bool isFocused = false;
  int textCounter = 0;
  bool notValidated = false;

  bool obscure = true;

  // final _formKey = GlobalKey<FormState>();

  ScrollController _scrollController = ScrollController();
  @override
  void initState() {
    super.initState();
    if (widget.textCtrl != null) {
      currentValue = widget.textCtrl!.text;
    }
    if (widget.initialValue != null) {
      currentValue = widget.initialValue!;
    }
    _labelFocusNode = FocusNode();
    _labelFocusNode!.addListener(() {
      if (_labelFocusNode!.hasFocus) {
        setState(() {
          isFocused = true;
        });
        return;
      }
      setState(() {
        isFocused = false;
      });
    });
  }

  @override
  void dispose() {
    _labelFocusNode!.dispose();
    super.dispose();
  }

  void _requestFocus() {
    setState(() {
      FocusScope.of(context).requestFocus(_labelFocusNode);
    });
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      child: Container(
        constraints: BoxConstraints(maxHeight: widget.height),
        width: MediaQuery.of(context).size.width * 0.9,
        child: Stack(
          children: [
            Column(
              children: [
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    widget.labelWidget ??
                        Row(
                          children: [
                            Text(
                              widget.labelText,
                              style: RothkoTextStyles.caption.copyWith(
                                  fontWeight: FontWeight.w500,
                                  color: RothkoCache.getTheme!(context) ==
                                          ThemeMode.light
                                      ? RothkoColor.kDarkNeutralDarken1
                                      : RothkoColor.kLightNeutralDarken1,
                                  letterSpacing: .02),
                            ),
                            SizedBox(
                              width: 5.1,
                            ),
                            RothkoTooltipWithAction(
                                onDismiss: () {},
                                title: 'Textfield',
                                message: widget.toolTipText ?? '',
                                stepperLength: 2,
                                stepperPosition: 1,
                                toolTipInfo: [],
                                primaryBtnOnTap: widget.toolTipAction ?? () {},
                                triggerWidget: Icon(
                                  Icons.info,
                                  color: RothkoColor.kPrimaryBase,
                                  size: 20,
                                ),
                                direction: AxisDirection.up,
                                toolTipHeight: 200.0),
                          ],
                        ),
                    if (widget.maxlength != null && widget.enabled != false)
                      Text(
                        "$textCounter/${widget.maxlength}",
                        style: RothkoTextStyles.caption.copyWith(
                          fontWeight: FontWeight.w400,
                          color: notValidated
                              ? RothkoColor.kErrorBase
                              : RothkoCache.getTheme!(context) ==
                                      ThemeMode.light
                                  ? RothkoColor.kDarkNeutralbase
                                  : RothkoColor.kLightNeutralDarken2,
                        ),
                      ),
                  ],
                ),
                SizedBox(
                  height: 4,
                ),
                Scrollbar(
                  controller: _scrollController,
                  isAlwaysShown: true,
                  child: TextFormField(
                    obscureText: widget.showSuffixIcon ? obscure : false,
                    scrollController: _scrollController,
                    scrollPadding: EdgeInsets.only(right: 1000),
                    initialValue: widget.initialValue,
                    autovalidateMode: AutovalidateMode.onUserInteraction,
                    enableSuggestions: widget.enableSuggestions,
                    inputFormatters: widget.inputFormatters,
                    keyboardType:
                        widget.keyboardType ?? TextInputType.multiline,
                    onChanged: (value) {
                      if (widget.onChanged != null) {
                        widget.onChanged!(value);
                      }
                      textCounter = value.length;

                      setState(() {});
                    },
                    validator: (val) {
                      if (widget.validator != null) {
                        String? value = widget.validator!(val);

                        if (value != null) {
                          notValidated = true;
                          return value;
                        } else {
                          notValidated = false;
                        }
                      }
                    },
                    maxLines: widget.maxlines,
                    minLines: 1,
                    maxLength: widget.maxlength,
                    enabled: widget.enabled,
                    readOnly: widget.readOnly!,
                    controller: widget.textCtrl ?? _textfieldController,
                    cursorColor:
                        RothkoCache.getTheme!(context) == ThemeMode.light
                            ? kDarkNeutralBase
                            : kLightNeutralBase,
                    cursorHeight: 16.0,
                    focusNode: _labelFocusNode,
                    onTap: _requestFocus,
                    style: TextStyle(
                        color:
                            RothkoCache.getTheme!(context) == ThemeMode.light &&
                                    widget.enabled!
                                ? kDarkNeutralBase
                                : RothkoCache.getTheme!(context) ==
                                            ThemeMode.light &&
                                        !widget.enabled!
                                    ? kDarkNeutralLighten4
                                    : RothkoCache.getTheme!(context) ==
                                                ThemeMode.dark &&
                                            !widget.enabled!
                                        ? kPrimaryLighten3
                                        : kLightNeutralBase,
                        fontFamily: 'Graphik',
                        fontSize: 16.0,
                        fontWeight: FontWeight.w400),
                    decoration: InputDecoration(
                      suffixIcon: widget.showSuffixIcon == true
                          ? GestureDetector(
                              onTap: () {
                                obscure = !obscure;
                                setState(() {});
                              },
                              child: Icon(
                                obscure
                                    ? Icons.visibility
                                    : Icons.visibility_off_outlined,
                                color: RothkoColor.kDarkNeutralLighten1,
                              ),
                            )
                          : null,
                      counterText: "",
                      hintText: widget.hintText,
                      hintStyle: widget.hintStyle ??
                          RothkoTextStyles.bodyText2.copyWith(
                            color: widget.enabled == false
                                ? RothkoColor.kDarkNeutralLighten1
                                : !_labelFocusNode!.hasFocus
                                    ? RothkoColor.kDarkNeutralLighten1
                                    : RothkoColor.kDarkNeutralDarken2,
                            fontWeight: FontWeight.w400,
                          ),
                      errorStyle: TextStyle(color: RothkoColor.kErrorBase),
                      errorBorder: OutlineInputBorder(
                          borderRadius: BorderRadius.circular(widget.radius),
                          borderSide:
                              BorderSide(color: RothkoColor.kErrorBase)),
                      focusedBorder: OutlineInputBorder(
                          borderRadius: BorderRadius.circular(widget.radius),
                          borderSide: BorderSide(
                              color: RothkoCache.getTheme!(context) ==
                                      ThemeMode.light
                                  ? RothkoColor.kPrimaryBase
                                  : kDarkNeutralLighten2)),
                      filled: widget.enabled == false,
                      fillColor: RothkoCache.getTheme!(context) ==
                                  ThemeMode.light &&
                              !_labelFocusNode!.hasFocus
                          ? widget.enabled == false
                              ? RothkoColor.kLightNeutralLighten1
                              : RothkoColor.kLightNeutralLighten2
                          : RothkoCache.getTheme!(context) == ThemeMode.light &&
                                  _labelFocusNode!.hasFocus &&
                                  widget.enabled!
                              ? kLightNeutralLighten4
                              : RothkoCache.getTheme!(context) ==
                                          ThemeMode.dark &&
                                      !_labelFocusNode!.hasFocus
                                  ? kDarkNeutralBase
                                  : kDarkNeutralLighten1,
                      helperText: widget.helperHint,
                      alignLabelWithHint: true,
                      helperStyle: RothkoTextStyles.caption.copyWith(
                        color: RothkoColor.kDarkNeutralbase,
                        fontWeight: FontWeight.w400,
                        letterSpacing: 0,
                      ),
                      enabledBorder: OutlineInputBorder(
                          borderRadius: BorderRadius.circular(widget.radius),
                          borderSide: BorderSide(
                              color: RothkoCache.getTheme!(context) ==
                                      ThemeMode.light
                                  ? RothkoColor.kLightNeutralDarken1
                                  : kDarkNeutralLighten2)),
                      disabledBorder: OutlineInputBorder(
                          borderRadius: BorderRadius.circular(widget.radius),
                          borderSide: BorderSide(
                              color: RothkoCache.getTheme!(context) ==
                                      ThemeMode.light
                                  ? RothkoColor.kLightNeutralDarken2
                                  : kDarkNeutralLighten2)),
                      border: OutlineInputBorder(
                          borderRadius: BorderRadius.circular(widget.radius),
                          borderSide: BorderSide(
                              color: RothkoCache.getTheme!(context) ==
                                      ThemeMode.light
                                  ? kLightNeutralLighten1
                                  : kDarkNeutralLighten2)),
                    ),
                  ),
                ),
              ],
            ),
          ],
        ),
      ),
      onTap: () {
        setState(() {
          fillColor = RothkoCache.getTheme!(context) == ThemeMode.light
              ? kLightNeutralLighten4
              : kLightNeutralLighten1;
        });
      },
    );
  }
}
