import 'package:flutter/material.dart';
import 'package:rothko_mobile/rothko.dart';
import 'package:rothko_mobile/rothko_system/steppers/default_stepper.dart';
import 'package:rothko_mobile/rothko_system/tooltip/rothko_tooltip.dart';

import 'package:rothko_mobile/rothko_system/utilities/textstyles.dart';
import 'package:smooth_page_indicator/smooth_page_indicator.dart';

class RothkoTooltipWithAction extends StatefulWidget {
  final double toolTipHeight;
  final AxisDirection direction;
  final String? secondaryBtnText, primaryBtnText;
  final Color? activeStepperColor;

  final Widget triggerWidget;
  final String title, message;
  final Function()? secondaryBtnOnTap, primaryBtnOnTap, onDismiss;
  final double stepperLength, stepperPosition;
  final List toolTipInfo;

  const RothkoTooltipWithAction(
      {Key? key,
      required this.stepperLength,
      this.activeStepperColor,
      required this.stepperPosition,
      required this.title,
      required this.message,
      required this.toolTipHeight,
      required this.direction,
      required this.toolTipInfo,
      required this.onDismiss,
      this.secondaryBtnText,
      this.primaryBtnText,
      this.secondaryBtnOnTap,
      this.primaryBtnOnTap,
      required this.triggerWidget})
      : super(
          key: key,
        );

  @override
  State<RothkoTooltipWithAction> createState() =>
      _RothkoTooltipWithActionState();
}

class _RothkoTooltipWithActionState extends State<RothkoTooltipWithAction> {
  PageController scrollController = PageController();

  @override
  Widget build(BuildContext context) {
    return RothkoTooltip(
        content: [
          Expanded(
            child: Container(
              width: MediaQuery.of(context).size.width,
              child: ListView.builder(
                  controller: scrollController,
                  scrollDirection: Axis.horizontal,
                  itemCount: widget.stepperLength.toInt(),
                  itemBuilder: (context, stepperPosition) {
                    return Column(
                      mainAxisSize: MainAxisSize.min,
                      mainAxisAlignment: MainAxisAlignment.start,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Container(
                          width: MediaQuery.of(context).size.width * 0.9,
                          child: Row(
                            mainAxisAlignment: MainAxisAlignment.spaceBetween,
                            crossAxisAlignment: CrossAxisAlignment.center,
                            children: [
                              Text(widget.title,
                                  style: RothkoTextStyles.caption.copyWith(
                                      color:
                                          RothkoColor.kLightNeutralLighten2)),
                              IconButton(
                                  onPressed: widget.onDismiss,
                                  icon: Icon(
                                    Icons.close,
                                    size: 16,
                                    color: RothkoColor.kLightNeutralLighten2,
                                  )),
                            ],
                          ),
                        ),
                        SizedBox(
                          height: 12.0,
                        ),
                        Text(
                          widget.message,
                          style: RothkoTextStyles.caption.copyWith(
                              color: RothkoColor.kLightNeutralDarken2,
                              fontWeight: FontWeight.normal),
                        ),
                        SizedBox(
                          height: 12.0,
                        ),
                      ],
                    );
                  }),
            ),
          ),
          Container(
            width: MediaQuery.of(context).size.width,
            height: 40.0,
            child: Row(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  SmoothPageIndicator(
                    controller: scrollController,
                    count: widget.stepperLength.toInt(),
                    effect: SlideEffect(
                        activeDotColor: widget.activeStepperColor ??
                            RothkoColor.kPrimaryBase,
                        dotHeight: 8.0,
                        dotWidth: 8.0),
                  ),
                  Container(
                    width: MediaQuery.of(context).size.width * 0.45,
                    child: Row(
                      children: [
                        Expanded(
                          child: RothkoButton(
                              text: 'Skip',
                              filled: false,
                              border: false,
                              textColor: RothkoColor.kLightNeutralLighten1,
                              disabled: false,
                              onPressed: () {
                                scrollController.jumpToPage(
                                    widget.stepperLength.toInt() - 1);
                                widget.secondaryBtnOnTap!.call();
                              }),
                        ),
                        Expanded(
                          child: RothkoButton(
                              text: widget.primaryBtnText ?? 'Next',
                              filled: true,
                              color: RothkoColor.kPrimaryBase,
                              border: false,
                              textColor: RothkoColor.kLightNeutralLighten1,
                              disabled: false,
                              onPressed: () {
                                scrollController.nextPage(
                                    duration: Duration(milliseconds: 300),
                                    curve: Curves.ease);
                                widget.primaryBtnOnTap!.call();
                              }),
                        )
                      ],
                    ),
                  )
                ]),
          )
        ],
        toolTipHeight: widget.toolTipHeight,
        direction: widget.direction,
        triggerWidget: widget.triggerWidget);
  }
}
