import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:rothko_mobile/rothko.dart';

import 'package:rothko_mobile/rothko_system/BottomSheet/confirmation.dart';
import 'package:rothko_mobile/rothko_system/BottomSheet/standard.dart';
import 'package:rothko_mobile/rothko_system/avatar/group_avatar.dart';
import 'package:rothko_mobile/rothko_system/banners/banner_filled_button.dart';
import 'package:rothko_mobile/rothko_system/banners/fixed_banner.dart';
import 'package:rothko_mobile/rothko_system/banners/banner_outline_button.dart';
import 'package:rothko_mobile/rothko_system/buttons/icon_button.dart';

import 'package:rothko_mobile/rothko_system/charts/circular-indicator.dart';
import 'package:rothko_mobile/rothko_system/charts/linear_progress_indicator.dart';
import 'package:rothko_mobile/rothko_system/charts/rotate-indicator.dart';
import 'package:rothko_mobile/rothko_system/checkbox/checkbox.dart';

import 'package:rothko_mobile/rothko_system/dialog/default_dialog.dart';
import 'package:rothko_mobile/rothko_system/dialog/dialog_scrollable.dart';
import 'package:rothko_mobile/rothko_system/dialog/form_dialog.dart';
import 'package:rothko_mobile/rothko_system/display_states/display_states.dart';
import 'package:rothko_mobile/rothko_system/snackbar/snackbar.dart';
import 'package:rothko_mobile/rothko_system/snackbar/snackbar_helper.dart';
import 'package:rothko_mobile/rothko_system/steppers/default_stepper.dart';
import 'package:rothko_mobile/rothko_system/switches/switches.dart';
import 'package:rothko_mobile/rothko_system/tabs/tabs.dart';
import 'package:rothko_mobile/rothko_system/tabs/tabs_dynamic.dart';
import 'package:rothko_mobile/rothko_system/textfields/clearable.dart';
import 'package:rothko_mobile/rothko_system/textfields/rothko-textfield.dart';
import 'package:rothko_mobile/rothko_system/textfields/dense-default.dart';
import 'package:rothko_mobile/rothko_system/textfields/password.dart';
import 'package:rothko_mobile/rothko_system/textfields/rothko_textfield.dart';
import 'package:rothko_mobile/rothko_system/textfields/withSuffixText.dart';
import 'package:rothko_mobile/rothko_system/tooltip/default.dart';
import 'package:rothko_mobile/rothko_system/tooltip/rothko_tooltip.dart';
import 'package:rothko_mobile/rothko_system/tooltip/withAction.dart';
import 'package:rothko_mobile/rothko_system/tooltip/withTitle.dart';
import 'package:rothko_mobile/rothko_system/utilities/textstyles.dart';
import 'package:rothko_mobile/widgets/story.dart';
import 'package:rothko_mobile/widgets/storybook.dart';

import '../rothko_system/toggle/index.dart';

class StoryApp extends StatelessWidget {
  final GlobalKey<ScaffoldState> _scaffoldKey = new GlobalKey<ScaffoldState>();
  @override
  Widget build(BuildContext context) => Scaffold(
      key: _scaffoldKey,
      body: Storybook(
        children: [
          ///create classes for each widgets in appropriate named folders under ./rothko_system
          ///logo starts here
          Story(
            section: 'Logo',
            name: 'Bento Logo Normal',
            padding: EdgeInsets.all(5), // optional padding customization

            builder: (_, k) => BentoLogoNormal(
              urlType: k.options('Logo Variation',
                  initial: "assets/img/bento_logonormal.png",
                  options: [
                    Option('Variation 1', "assets/img/bento_logonormal.png"),
                    Option('Variation 2', "assets/img/bento_logonormal2.png")
                  ]),
            ),
          ),
          Story(
            section: 'Logo',
            name: 'Bento Logomark',
            padding: EdgeInsets.all(5), // optional padding customization

            builder: (_, k) => BentoLogomark(
              urlType: k.options('Logomark Variation',
                  initial: "assets/img/bento_logomark.png",
                  options: [
                    Option('Variation 1', "assets/img/bento_logomark.png"),
                    Option('Variation 2', "assets/img/bento_logomark2.png")
                  ]),
            ),
          ),
          Story.simple(
            section: 'Logo',
            name: 'Bento Wordmark',
            padding: EdgeInsets.all(5), // optional padding customization
            child: BentoWordmark(),
          ),
          //bento Logo ends

          //people logo starts
          Story(
            section: 'Logo',
            name: 'People Logo Normal',
            padding: EdgeInsets.all(5), // optional padding customization

            builder: (_, k) => PeopleLogoNormal(
              urlType: k.options('Logo Variation',
                  initial: "assets/img/people_logonormal.png",
                  options: [
                    Option('Variation 1', "assets/img/people_logonormal.png"),
                    Option('Variation 2', "assets/img/people_logonormal2.png")
                  ]),
            ),
          ),
          Story(
            section: 'Logo',
            name: 'People Logomark',
            padding: EdgeInsets.all(5), // optional padding customization

            builder: (_, k) => PeopleLogomark(
              urlType: k.options('Logomark Variation',
                  initial: "assets/img/people_logomark.png",
                  options: [
                    Option('Variation 1', "assets/img/people_logomark.png"),
                    Option('Variation 2', "assets/img/people_logomark2.png")
                  ]),
            ),
          ),

          //people logo ends

          ///logo ends here

          ///AVATAR STARTS HERE

          Story(
            section: 'Avatar',
            name: 'Default Outline',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => DefaultOutlineAvatar(
              outlineColor: k.options(
                "Color",
                initial: kSuccessBase,
                options: [
                  Option('Purple', kAccentBase),
                  Option('Green', kSuccessBase),
                  Option('Orange', kWarningBase),
                  Option('Red', kErrorBase),
                ],
              ),
            ),
          ),

          Story(
            section: 'Avatar',
            name: 'Default Filled',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => DefaultFillAvatar(
                // backgroundImage:
                //     AssetImage('assets/img/personas/circle-user2.png'),
                ),
          ),

          Story(
            section: 'Avatar',
            name: 'Rothko Avatar',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => RothkoAvatar(
              name: k.text('title', initial: 'Cole Gbolahan'),
              color: k.options(
                'colors',
                initial: RothkoColor.kWarningDarken2,
                options: [
                  Option('Warning', RothkoColor.kWarningDarken2),
                  Option('Red', RothkoColor.kErrorDarken1),
                  Option('Accent', RothkoColor.kAccentDarken1),
                  Option('Success', RothkoColor.kSuccessDarken1),
                  Option('Primary', RothkoColor.kPrimaryDarken1)
                ],
              ),
              size: k.options('Sizes', initial: AvatarSize.small, options: [
                Option('Small', AvatarSize.small),
                Option('Normal', AvatarSize.normal),
                Option('Large', AvatarSize.large),
                Option('XLarge', AvatarSize.xLarge),
                Option('XXLarge', AvatarSize.xxLarge),
              ]),
              urlType: k.options('Personas',
                  initial: "assets/img/personas/circle-user.png",
                  options: [
                    Option(
                        'Variation 1', "assets/img/personas/circle-user.png"),
                    Option(
                        'Variation 2', "assets/img/personas/circle-user2.png"),
                    Option(
                        'Variation 3', "assets/img/personas/circle-user3.png"),
                    Option(
                        'Variation 4', "assets/img/personas/circle-user4.png"),
                    Option(
                        'Variation 5', "assets/img/personas/circle-user5.png"),
                    Option('No Image', null),
                    Option("network image",
                        "https://res.cloudinary.com/dzf6wnlah/image/upload/v1660135241/escrow/pre5tcblbvsa7tnwahyh.jpg")
                  ]),
            ),
          ),
          Story(
            section: 'Avatar',
            name: 'Rothko Group Avatar',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => RothkoGroupAvatar(
              // namesAndImages: ["GG HH", "GU NH"],
              // namesAndImages: [
              //   "assets/img/personas/circle-user.png",
              //   "assets/img/personas/circle-user2.png",
              //   "assets/img/personas/circle-user3.png",
              //   "assets/img/personas/circle-user4.png",
              //   "assets/img/personas/circle-user5.png"
              // ],
              namesAndImages: [
                "GG HH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "GG HH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "GG HH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "GG HH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "GG HH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "GG HH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
                "assets/img/personas/circle-user4.png",
                "Cole Gbolahan",
                "assets/img/personas/circle-user3.png",
                "assets/img/personas/circle-user4.png",
                "assets/img/personas/circle-user5.png",
                "GG HH",
                "GU NH",
              ],

              showBorder: true,
              color: k.options(
                'colors',
                initial: RothkoColor.kWarningDarken2,
                options: [
                  Option('Warning', RothkoColor.kWarningDarken2),
                  Option('Red', RothkoColor.kErrorDarken1),
                  Option('Accent', RothkoColor.kAccentDarken1),
                  Option('Success', RothkoColor.kSuccessDarken1),
                  Option('Primary', RothkoColor.kPrimaryDarken1)
                ],
              ),
              size: k.options('Sizes', initial: AvatarSize.small, options: [
                Option('Small', AvatarSize.small),
                Option('Normal', AvatarSize.normal),
              ]),
            ),
          ),
          Story(
            section: 'Avatar',
            name: 'Square Outline',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => SquareAvatarOutline(
              size: 48.0,
              avatarColor:
                  k.options('Avatar Color', initial: kSuccessBase, options: [
                Option('Green', kSuccessBase),
                Option('Red', kErrorBase),
                Option('Orange', kWarningBase),
                Option('Purple', kAccentBase),
              ]),

              /// if passed image of avatar is plugged either network or asset
              // profileDecorImgType:
              //     AssetImage('assets/img/personas/circle-user2.png'),
              username: k.text('Username', initial: 'Bento Mobile'),
              profileImageUrl: k.options('Personas',
                  initial: "assets/img/personas/circle-user3.png",
                  options: [
                    Option('No Image', ""),
                    Option(
                        'Variation 2', "assets/img/personas/circle-user2.png"),
                    Option(
                        'Variation 3', "assets/img/personas/circle-user3.png"),
                    Option(
                        'Variation 4', "assets/img/personas/circle-user4.png"),
                    Option(
                        'Variation 5', "assets/img/personas/circle-user5.png"),
                  ]),
            ),
          ),

          Story(
            section: 'Avatar',
            name: 'Square Filled',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => SquareAvatarFilled(
              size: 48.0,
              avatarColor:
                  k.options('Avatar Color', initial: kSuccessBase, options: [
                Option('Green', kSuccessBase),
                Option('Red', kErrorBase),
                Option('Orange', kWarningBase),
                Option('Purple', kAccentBase),
              ]),
              username: k.text('Username', initial: 'Bento Mobile'),

              /// if passed image of avatar is plugged either network or asset
              // profileDecorImgType:
              //     AssetImage('assets/img/personas/circle-user2.png'),
              profileImageUrl: k.options('Personas',
                  initial: "assets/img/personas/circle-user2.png",
                  options: [
                    Option('No Image', ""),
                    Option(
                        'Variation 2', "assets/img/personas/circle-user2.png"),
                    Option(
                        'Variation 3', "assets/img/personas/circle-user3.png"),
                    Option(
                        'Variation 4', "assets/img/personas/circle-user4.png"),
                    Option(
                        'Variation 5', "assets/img/personas/circle-user5.png"),
                  ]),
            ),
          ),

          ///AVATAR ENDS
          ///
          ///steppers
          Story(
              section: 'Stepper',
              name: 'Default Stepper',
              // padding: EdgeInsets.all(5), // optional padding customization
              builder: (_, k) => RothkoSteppers(
                    totalSteps: k
                        .number(
                          'Total steps',
                          initial: 3,
                        )
                        .toInt(),
                    currentStep: k
                        .number(
                          'Current step',
                          initial: 2,
                        )
                        .toInt(),
                    padding: k
                        .number(
                          'Padding',
                          initial: 4,
                        )
                        .toDouble(),
                    size: k.number('Size', initial: 4).toDouble(),

                    selectedColor: k.options(
                      'Selected Color',
                      initial: RothkoColor.kPrimaryBase,
                      options: [
                        Option('Normal', RothkoColor.kPrimaryBase),
                        Option('Lighten5', RothkoColor.kErrorBase)
                      ],
                    ),
                    unselectedColor: k.options(
                      'Unselected Color',
                      initial: RothkoColor.kLightNeutralDarken1,
                      options: [
                        Option('Normal', RothkoColor.kLightNeutralDarken1),
                        Option('Red', RothkoColor.kErrorLighten2),
                      ],
                    ),
                    stepperSize: k.options(
                      'Stepper Size',
                      initial: StepperSize.MEDIUM,
                      options: [
                        Option('Medium', StepperSize.MEDIUM),
                        Option('Small', StepperSize.SMALL),
                        Option('xSmall', StepperSize.XSMALL),
                      ],
                    ),

                    // customStep: k.options(
                    //   'Custom ',
                    //   initial: (index, color, d) {
                    //     if (index == 0 || index == 3 || index == 9) {
                    //       return Icon(
                    //         Icons.ac_unit,
                    //         color: color,
                    //       );
                    //     } else if (index == 1 || index == 6) {
                    //       return Icon(
                    //         Icons.sentiment_satisfied,
                    //         color: color,
                    //       );
                    //     } else {
                    //       return Icon(
                    //         Icons.trending_up,
                    //         color: color,
                    //       );
                    //     }
                    //   },
                    // )
                  )),

          ///badges begin

          Story(
              section: 'Badges',
              name: 'Primary Badge',
              // padding: EdgeInsets.all(5), // optional padding customization
              builder: (_, k) => RothkoBadge(
                    text: k.text('Text', initial: '12'),
                    primary: true,
                    textColor: k.options(
                      'Text Color',
                      initial: kPrimaryLighten0,
                      options: [
                        Option('Normal', kPrimaryLighten0),
                        Option('Lighten5', kPrimaryBase)
                      ],
                    ),
                    badgeSize: k.options(
                      'Badge Size',
                      initial: BadgeSize.NORMAL,
                      options: [
                        Option('Small', BadgeSize.SMALL),
                        Option('Normal', BadgeSize.NORMAL),
                        Option('Large', BadgeSize.LARGE)
                      ],
                    ),
                    badgeType: k.options(
                      'Badge Type',
                      initial: BadgeType.ANNOUNCEMENT,
                      options: [
                        Option('Announcement', BadgeType.ANNOUNCEMENT),
                        Option('Muted', BadgeType.MUTED),
                        Option('Pronounced', BadgeType.PRONOUNCED)
                      ],
                    ),
                    bgColor: k.options(
                      'Background Color',
                      initial: kPrimaryBase,
                      options: [
                        Option('Normal', kPrimaryBase),
                        Option('Lighten5', kPrimaryLighten5)
                      ],
                    ),
                  )),

          Story(
              section: 'Badges',
              name: 'Success Badge',
              // padding: EdgeInsets.all(5), // optional padding customization
              builder: (_, k) => RothkoBadge(
                    text: k.text('Text', initial: '12'),
                    textColor: k.options(
                      'Text Color',
                      initial: kPrimaryLighten0,
                      options: [
                        Option('Normal', kPrimaryLighten0),
                        Option('Lighten5', kSuccessBase)
                      ],
                    ),
                    bgColor: k.options(
                      'Background Color',
                      initial: kSuccessBase,
                      options: [
                        Option('Normal', kSuccessBase),
                        Option('Lighten5', kSuccessLighten5)
                      ],
                    ),
                  )),

          Story(
              section: 'Badges',
              name: 'Accent Badge',
              // padding: EdgeInsets.all(5), // optional padding customization
              builder: (_, k) => RothkoBadge(
                    text: k.text('Text', initial: '12'),
                    textColor: k.options(
                      'Text Color',
                      initial: kPrimaryLighten0,
                      options: [
                        Option('Normal', kPrimaryLighten0),
                        Option('Lighten5', kAccentBase)
                      ],
                    ),
                    bgColor: k.options(
                      'Background Color',
                      initial: kAccentBase,
                      options: [
                        Option('Normal', kAccentBase),
                        Option('Lighten5', kAccentLighten5)
                      ],
                    ),
                  )),

          Story(
              section: 'Badges',
              name: 'Warning Badge',
              // padding: EdgeInsets.all(5), // optional padding customization
              builder: (_, k) => RothkoBadge(
                    text: k.text('Text', initial: '12'),
                    textColor: k.options(
                      'Text Color',
                      initial: kPrimaryLighten0,
                      options: [
                        Option('Normal', kPrimaryLighten0),
                        Option('Lighten5', kWarningBase)
                      ],
                    ),
                    bgColor: k.options(
                      'Background Color',
                      initial: kWarningBase,
                      options: [
                        Option('Normal', kWarningBase),
                        Option('Lighten5', kWarningLighten5)
                      ],
                    ),
                  )),

          Story(
              section: 'Badges',
              name: 'Error Badge',
              // padding: EdgeInsets.all(5), // optional padding customization
              builder: (_, k) => RothkoBadge(
                    text: k.text('Text', initial: '12'),
                    textColor: k.options(
                      'Text Color',
                      initial: kPrimaryLighten0,
                      options: [
                        Option('Normal', kPrimaryLighten0),
                        Option('Lighten5', kErrorBase)
                      ],
                    ),
                    bgColor: k.options(
                      'Background Color',
                      initial: kErrorBase,
                      options: [
                        Option('Normal', kErrorBase),
                        Option('Lighten5', kErrorLighten5)
                      ],
                    ),
                  )),

          Story(
              section: 'Badges',
              name: 'Positioned Badges',
              // padding: EdgeInsets.all(5), // optional padding customization
              builder: (_, k) => BadgesPostioned(
                  text: k.text('Text', initial: '12'),
                  overlapping:
                      k.options("Overlapping", initial: false, options: [
                    Option('True', true),
                    Option('False', false),
                  ]),
                  type: k.options("Type", initial: 'badge', options: [
                    Option('Badge', 'badge'),
                    Option('Dot', 'dot'),
                  ]),
                  alignment: k.options(
                    'Alignment',
                    initial: Alignment.bottomRight,
                    options: [
                      Option('Bottom Right', Alignment.bottomRight),
                      Option('Bottom Left', Alignment.bottomLeft),
                      Option('Top Left', Alignment.topLeft),
                      Option('Top Right', Alignment.topRight),
                    ],
                  ),
                  textColor: kPrimaryBase,
                  bgColor: kPrimaryLighten5)),

          ///badges end

          ///Gradients starts here
          Story(
            section: 'Gradients',
            name: 'Primary Gradients',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => PrimaryGradient(
              height: k.slider('height', initial: 50.0, max: 200.0, min: 50.0),
              width: k.slider('width', initial: 100.0, max: 200.0, min: 50.0),
              radius: k.slider('radius', initial: 0.5, max: 1.0, min: 0.1),
            ),
          ),

          Story(
            section: 'Gradients',
            name: ' Warning Gradients',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => WarningGradient(
              height: k.slider('height', initial: 50.0, max: 200.0, min: 50.0),
              width: k.slider('width', initial: 100.0, max: 200.0, min: 50.0),
              radius: k.slider('radius', initial: 0.5, max: 1.0, min: 0.1),
            ),
          ),

          Story(
            section: 'Gradients',
            name: ' Accent Gradients',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => AccentGradient(
              height: k.slider('height', initial: 50.0, max: 200.0, min: 50.0),
              width: k.slider('width', initial: 100.0, max: 200.0, min: 50.0),
              radius: k.slider('radius', initial: 0.8, max: 1.0, min: 0.1),
            ),
          ),
          Story(
            section: 'Gradients',
            name: ' Error Gradients',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => ErrorGradient(
              height: k.slider('height', initial: 50.0, max: 200.0, min: 50.0),
              width: k.slider('width', initial: 100.0, max: 200.0, min: 50.0),
              radius: k.slider('radius', initial: 0.5, max: 1.0, min: 0.1),
            ),
          ),
          Story(
            section: 'Gradients',
            name: ' Success Gradients',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => SuccessGradient(
              height: k.slider('height', initial: 50.0, max: 200.0, min: 50.0),
              width: k.slider('width', initial: 100.0, max: 200.0, min: 50.0),
              radius: k.slider('radius', initial: 0.5, max: 1.0, min: 0.1),
            ),
          ),

          /// GRADIENT ENDS HERE
          /// SEARCH BEGIN HERE

          Story.simple(
              section: 'Display State',
              name: 'Large Empty display ',
              padding: EdgeInsets.all(5), // optional padding customization
              child: RothkoDisplayStates(
                primaryBtnText: 'Button text',
                secondaryBtnText: 'Button text',
                isErrorDisplay: true,
                subheading: 'Click on the “Add Details” button to get started',
                heading: 'You have not added any details',
              )),
          Story.simple(
              section: 'Display State',
              name: 'Small Error display ',
              padding: EdgeInsets.all(5), // optional padding customization
              child: Center(
                child: RothkoDisplayStates(
                  isErrorDisplay: true,
                  primaryBtnText: 'Button text',
                  secondaryBtnText: 'Button text',
                  subheading: 'Click on the Try Again button to try again',
                  heading: 'Something went wrong',
                ),
              )),

          /// SEARCH END HERE
          /// SEARCH BEGIN HERE

          Story.simple(
            section: 'Search',
            name: 'Default',
            padding: EdgeInsets.all(5), // optional padding customization
            child: RothkoSearchBox(
              label: 'Label',
              enabled: true,
              hint: "Search",
              readOnly: false,
            ),
          ),

          /// SEARCH END HERE

          ///CHIPS BEGIN HER

          Story(
            section: 'Chips',
            name: 'Basic Chips',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => RothkoBasicChips(
              chipColor: k.options(
                'Chip Color',
                initial: RothkoColor.kPrimaryLighten2,
                options: [
                  Option('Primary Muted', RothkoColor.kPrimaryLighten2),
                  Option('Success Muted', RothkoColor.kSuccessLighten2),
                  Option('Accent Muted', RothkoColor.kAccentLighten2),
                  Option('Warning Muted', RothkoColor.kWarningLighten2),
                  Option('Error Muted', RothkoColor.kErrorLighten2),
                  Option('Secondary Muted', RothkoColor.kSecondaryLighten2),
                  Option('Neutral Muted', RothkoColor.kLightNeutralBase),
                  Option('Primary Pronounced', RothkoColor.kPrimaryLighten1),
                  Option('Success Pronounced', RothkoColor.kSuccessBase),
                  Option('Accent Pronounced', RothkoColor.kAccentLighten1),
                  Option('Warning Pronounced', RothkoColor.kWarningBase),
                  Option('Error Pronounced', RothkoColor.kErrorLighten1),
                  Option(
                    'Neutral Pronounced',
                    RothkoColor.kDarkNeutralbase,
                  )
                ],
              ),
              text: k.text('Chip label', initial: 'Chips'),
            ),
          ),

          Story(
            section: 'Chips',
            name: 'Dismissible-Default',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => RothkoDismissibleChip(
                deleteIconColor: RothkoColor.kErrorBase,
                withvatar: k.boolean('With Avatar', initial: false),
                withLeadingTitle: k.boolean(
                  'With Leading Title',
                  initial: false,
                ),
                username: k.text('Username', initial: 'Gbolahan Emeka'),
                avatarColor: RothkoColor.kErrorBase,
                labelColor: RothkoColor.kPrimaryBase,
                onDeleted: () {},
                chipColor: k.options(
                  'Chip Color',
                  initial: RothkoColor.kPrimaryLighten2,
                  options: [
                    Option('Primary Muted', RothkoColor.kPrimaryLighten2),
                    Option('Success Muted', RothkoColor.kSuccessLighten2),
                    Option('Accent Muted', RothkoColor.kAccentLighten2),
                    Option('Warning Muted', RothkoColor.kWarningLighten2),
                    Option('Error Muted', RothkoColor.kErrorLighten2),
                    Option('Secondary Muted', RothkoColor.kSecondaryLighten2),
                    Option('Neutral Muted', RothkoColor.kLightNeutralBase),
                    Option('Primary Pronounced', RothkoColor.kPrimaryLighten1),
                    Option('Success Pronounced', RothkoColor.kSuccessBase),
                    Option('Accent Pronounced', RothkoColor.kAccentLighten1),
                    Option('Warning Pronounced', RothkoColor.kWarningBase),
                    Option('Error Pronounced', RothkoColor.kErrorLighten1),
                    Option(
                      'Neutral Pronounced',
                      RothkoColor.kDarkNeutralbase,
                    )
                  ],
                ),
                text: k.text('label', initial: 'Chips'),
                leadingTitle: k.text('leading title', initial: 'chips'),
                profileImageUrl:
                    k.options('profile image', initial: '', options: [
                  Option('No Image', ""),
                  Option('Variation 2', "assets/img/personas/circle-user2.png"),
                  Option('Variation 3', "assets/img/personas/circle-user3.png"),
                  Option('Variation 4', "assets/img/personas/circle-user4.png"),
                  Option('Variation 5', "assets/img/personas/circle-user5.png"),
                ])),
          ),
          Story.simple(
              section: 'Chips',
              name: 'Avatar-Colored',
              padding: EdgeInsets.all(5), // optional padding customization
              // b
              child: ChipsAvatar(
                avatarColor: kDarkBackground,
              )),

          ///FormControl: TextFields
          Story.simple(
              section: 'TextField',
              name: 'v2 Textfield',
              child: RothkoTextFieldDefault(
                suffixWidget: Icon(Icons.ac_unit),
                helperHint: 'www.example.com',
                hasCounter: true,
                readOnly: false,
                enabled: true,
                label: 'me',
                maxlength: 20,
                showToolTip: true,
              )),
          Story.simple(
              section: 'TextField',
              name: 'v2 Textfield Password',
              child: RothkoTextfield(
                maxlines: 1,
                showSuffixIcon: true,
                helperHint: 'www.example.com',
                readOnly: false,
                enabled: true,
                maxlength: 20,
                labelText: 'rrrrrr',
              )),

          Story.simple(
              section: 'TextField',
              name: 'Dense - Textfield',
              child: TextFieldDense(
                readOnly: false,
                enabled: true,
                label: 'Label',
              )),

          Story.simple(
              section: 'TextField',
              name: 'Clearable - Textfield',
              child: TextFieldClearable(
                enabled: true,
                readOnly: false,
                label: 'Label',
              )),
          Story.simple(
              section: 'TextField',
              name: 'Password - Textfield',
              child: TextFieldPassword(
                enabled: true,
                readOnly: false,
                label: 'Label',
              )),
          Story.simple(
              section: 'TextField',
              name: 'Suffix- Textfield',
              child: TextFieldSuffixText(
                enabled: true,
                readOnly: false,
                label: 'Label',
                suffixString: '@mail.com',
              )),

          /// END TEXTFIELD

          /// BEGIN SELECT
          Story.simple(
              section: 'Select',
              name: 'Default - Select',
              child: SelectDefault(
                options: ['Select One', 'Select two', 'Select three'],
                labelText: 'Select',
                enabled: true,
                readonly: false,
                validator: (String? str) {
                  if (str == null || str.isEmpty) {
                    return 'Select Something';
                  }
                  return '';
                },
                labelTextColor: kDarkNeutralLighten3,
                suffixIcon: Icon(Icons.keyboard_arrow_down),
                selected: 'Select One',
                onChanged: (String? val) {},
              )),
          Story(
              section: 'Select',
              name: 'Default Dynamic - Select V2',
              builder: (context, builder) => SelectDefaultDynamic<dynamic>(
                    options: [
                      {
                        'name': 'Select One',
                        'icon': 'assets/img/personas/circle-user.png'
                      },
                      {
                        'name': 'Select Two',
                        'icon': 'assets/img/personas/circle-user3.png'
                      },
                      {
                        'name': 'Select Three',
                        'icon': 'assets/img/personas/circle-user4.png'
                      },
                      {
                        'name': 'Select Four',
                        'icon': 'assets/img/personas/circle-user5.png'
                      },
                    ],
                    labelText: 'Label',
                    enabled: true,
                    showTooltip: true,
                    hintText: 'Select item',
                    getText: (val) => val['name'] ?? '',
                    getIcons: (val) => val['icon'] ?? '',
                    hasIcons: true,
                    // hasAvatarIcons: true,
                    // inlineLabel: true,
                    labelAction: Text(
                      'Label action',
                      style: TextStyle(
                          fontWeight: FontWeight.w500, color: kPrimaryBase),
                    ),
                    readonly: false,
                    validator: (str) {
                      if (str == null || str.isEmpty) {
                        return 'Select Something';
                      }
                      return '';
                    },
                    labelTextColor: kDarkNeutralLighten3,
                    selected: null,
                    onChanged: (val) {},
                  )),
          Story.simple(
              section: 'Select',
              name: 'Dense - Select',
              child: DenseDefault(
                options: ['Select One', 'Select two', 'Select three'],
                labelText: 'Label',
                hintText: 'Select',
                enabled: true,
                readonly: false,
                validator: (String? str) {
                  if (str == null || str.isEmpty) {
                    return 'Select Something';
                  }
                  return '';
                },
                labelTextColor: kDarkNeutralLighten3,
                suffixIcon: Icon(Icons.keyboard_arrow_down),
                selected: null,
                onChanged: (String? val) {},
              )),

          Story.simple(
              section: 'Select',
              name: 'Icons - Select',
              child: IconsDefault(
                options: ['Select One', 'Select two', 'Select three'],
                labelText: 'Label',
                hintText: 'Select',
                enabled: true,
                readonly: false,
                validator: (String? str) {
                  if (str == null || str.isEmpty) {
                    return 'Select Something';
                  }
                  return '';
                },
                labelTextColor: kDarkNeutralLighten3,
                suffixIcon: Icon(Icons.keyboard_arrow_down),
                selected: null,
                onChanged: (String? val) {},
              )),

          Story.simple(
              section: 'Select',
              name: 'Hint - Select',
              child: HintDefault(
                options: ['Select One', 'Select two', 'Select three'],
                labelText: 'Label',
                hintText: 'Select your preferred location',
                enabled: true,
                readonly: false,
                validator: (String? str) {
                  if (str == null || str.isEmpty) {
                    return 'Select Something';
                  }
                  return '';
                },
                labelTextColor: kDarkNeutralLighten3,
                suffixIcon: Icon(Icons.keyboard_arrow_down),
                selected: null,
                onChanged: (String? val) {},
              )),

          //begin radios
          Story(
            section: 'Radios',
            name: 'Radio',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => RadioButton(
                color: k.options(
                  'Radio Color',
                  initial: kPrimaryBase,
                  options: [
                    Option('Primary Base', kPrimaryBase),
                    Option('Success Base', kSuccessBase),
                    Option('Accent Base', kAccentBase),
                    Option('Warning Base', kWarningBase),
                    Option('Error Base', kErrorBase),
                  ],
                ),
                enabled: k.boolean(
                  'Enabled',
                  initial: true,
                ),
                radioValue: true),
          ),
          //end radio

          //begin radios
          Story(
            section: 'Checkbox',
            name: 'Default Checkbox',
            builder: (_, k) => CheckboxButton(
                color: k.options(
                  'Checkbox Color',
                  initial: kPrimaryBase,
                  options: [
                    Option('Primary Base', kPrimaryBase),
                    Option('Success Base', kSuccessBase),
                    Option('Accent Base', kAccentBase),
                    Option('Warning Base', kWarningBase),
                    Option('Error Base', kErrorBase),
                  ],
                ),
                enabled: k.boolean(
                  'Enabled',
                  initial: true,
                ),
                value: true),
          ),
          //end radio

          ///SLIDERS BEGIN HERE
          Story(
            section: 'Slider',
            name: 'Simple Slider',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => SliderSimple(
              min: 0.0,
              max: 100.0,
              divisions: 1000,
              sliderColor: k.options(
                'Color',
                initial: kPrimaryBase,
                options: [
                  Option('Primary Base', kPrimaryBase),
                  Option('Success Base', kSuccessBase),
                  Option('Accent Base', kAccentBase),
                  Option('Warning Base', kWarningBase),
                  Option('Error Base', kErrorBase),
                ],
              ),
            ),
          ),
          Story(
            section: 'Slider',
            name: 'Paddle Slider',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => SliderPaddleShape(
              min: 0.0,
              max: 100.0,
              divisions: 1000,
              sliderColor: k.options(
                'Color',
                initial: kPrimaryBase,
                options: [
                  Option('Primary Base', kPrimaryBase),
                  Option('Success Base', kSuccessBase),
                  Option('Accent Base', kAccentBase),
                  Option('Warning Base', kWarningBase),
                  Option('Error Base', kErrorBase),
                ],
              ),
            ),
          ),

          /// TEXT AREA STARTS
          Story.simple(
              section: 'TextArea',
              name: 'Default - TextArea',
              child: TextAreaDefault(
                labelText: "ID Type",
                suffixIcon: Icons.location_on_outlined,
                helperHint: 'www.example.com',
                readOnly: false,
                enabled: true,
                hintText: 'Enter text here',
                maxlength: 240,
                maxlines: 2,
                validator: (val) {
                  if (val!.length < 5) {
                    return "Please enter a valid value";
                  }
                },
              )),
          Story.simple(
              section: 'TextArea',
              name: 'Clearable - TextArea',
              child: TextAreaClearable(
                readOnly: false,
                enabled: true,
                label: 'Label',
              )),

          Story(
              section: 'Button',
              name: 'IconButton',
              builder: (_, k) => RothkoIconButton(
                    loading: k.boolean('Loading', initial: false),
                    disabled: k.boolean('Diabled', initial: false),
                    transparent: k.boolean(
                      'Transparent',
                      initial: false,
                    ),
                    backgroundColor: k.options("BgColor Variation",
                        initial: RothkoColor.kPrimaryBase,
                        options: [
                          Option('Primary', RothkoColor.kPrimaryBase),
                          Option('Success', RothkoColor.kSuccessBase),
                          Option('Accent', RothkoColor.kAccentBase),
                          Option('Warning', RothkoColor.kWarningBase),
                          Option('Error', RothkoColor.kErrorBase),
                        ]),
                    rothkoIconColor: k.options("IconColor Variation",
                        initial: RothkoColor.kLightNeutralBase,
                        options: [
                          Option('White', RothkoColor.kLightNeutralBase),
                          Option('Primary', RothkoColor.kPrimaryBase),
                          Option('Success', RothkoColor.kSuccessBase),
                          Option('Accent', RothkoColor.kAccentBase),
                          Option('Warning', RothkoColor.kWarningBase),
                          Option('Error', RothkoColor.kErrorBase),
                        ]),
                    size: k.options("Size",
                        initial: IconButtonSize.NORMAL,
                        options: [
                          Option('Normal', IconButtonSize.NORMAL),
                          Option('Small', IconButtonSize.SMALL),
                          Option('XSmall', IconButtonSize.XSMALL),
                        ]),
                    buttonIcon: k.options('Icon',
                        initial: Icons.calendar_today,
                        options: [
                          Option(
                            'Date',
                            Icons.calendar_today,
                          ),
                          Option('Turned', Icons.turned_in_not_rounded),
                        ]),
                  )),
          Story(
              section: 'Button',
              name: 'RothkoButton',
              // padding: EdgeInsets.all(5), // optional padding customization
              builder: (_, k) => RothkoButton(
                    filled: k.boolean('Filled', initial: true),
                    border: k.boolean('Border', initial: true),
                    loading: k.boolean('Loading', initial: false),
                    disabled: k.boolean('Diabled', initial: false),
                    color: k.options("Color Variation",
                        initial: kPrimaryBase,
                        options: [
                          Option('Primary', kPrimaryBase),
                          Option('Success', kSuccessBase),
                          Option('Accent', kAccentBase),
                          Option('Warning', kWarningBase),
                          Option('Error', kErrorBase),
                        ]),
                    borderColor: k.options("BorderColor Variation",
                        initial: kPrimaryBase,
                        options: [
                          Option('Primary', kPrimaryBase),
                          Option('Success', kSuccessBase),
                          Option('Accent', kAccentBase),
                          Option('Warning', kWarningBase),
                          Option('Error', kErrorBase),
                        ]),
                    textColor: k.options("TextColor Variation",
                        initial: kLightNeutralBase,
                        options: [
                          Option('Primary', kPrimaryBase),
                          Option('Success', kSuccessBase),
                          Option('Accent', kAccentBase),
                          Option('Warning', kWarningBase),
                          Option('Error', kErrorBase),
                          Option('Light', kLightNeutralBase),
                        ]),
                    indicatorColor: k.options("IndicatorColor Variation",
                        initial: kLightNeutralLighten0,
                        options: [
                          Option('Primary Light', kPrimaryDarken1),
                          Option('Light', kLightNeutralLighten0),
                          Option('Success Light', kSuccessDarken1),
                          Option('Accent Light', kAccentDarken1),
                          Option('Warning Light', kWarningDarken1),
                          Option('Error Light', kErrorDarken1),
                        ]),
                    indicatorValueColor: k.options(
                        "IndicatorValueColor Variation",
                        initial: kPrimaryBase,
                        options: [
                          Option('Primary', kPrimaryBase),
                          Option('Success', kSuccessBase),
                          Option('Accent', kAccentBase),
                          Option('Warning', kWarningBase),
                          Option('Error', kErrorBase),
                        ]),
                    size:
                        k.options("Size", initial: ButtonSize.NORMAL, options: [
                      Option('Small', ButtonSize.SMALL),
                      Option('Normal', ButtonSize.NORMAL),
                      Option('Large', ButtonSize.LARGE),
                    ]),
                    text: k.text('Username', initial: 'Bento'),
                  )),

          Story.simple(
            section: 'Button',
            name: 'Full Screen Normal',
            padding: EdgeInsets.all(5), // optional padding customization
            child: RothkoButton(
              fullScreen: true,
              loading: true,
              size: ButtonSize.NORMAL,
              
              // icon: '',
              filled: true,
            ),
          ),
          Story.simple(
            section: 'Button',
            name: 'Full Screen Normal Outline',
            padding: EdgeInsets.all(5), // optional padding customization
            child: RothkoButton(
              fullScreen: true,
              loading: false,
              size: ButtonSize.NORMAL,
              // icon: '',
              filled: false,
            ),
          ),

          Story.simple(
            section: 'Button',
            name: 'Full Screen Large ',
            padding: EdgeInsets.all(5), // optional padding customization
            child: RothkoButton(
              fullScreen: true,
              loading: false,
              size: ButtonSize.LARGE,
              // icon: '',
              filled: true,
            ),
          ),

          Story.simple(
            section: 'Button',
            name: 'Full Screen Large Outline',
            padding: EdgeInsets.all(5), // optional padding customization
            child: RothkoButton(
              fullScreen: true,
              loading: false,
              size: ButtonSize.LARGE,
              // icon: '',
              text: "Bento",
              filled: false,
            ),
          ),
          Story(
            section: 'Paper',
            name: 'Paper',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => Paper(
              filled: k.boolean('filled', initial: false),
              hasElevation: k.boolean('Elevation', initial: true),
              spreadRadius: k.options('Spread Radius', initial: 24, options: [
                Option('-32', 32),
                Option('-24', 24),
              ]),
              height: k.options('Height', initial: 100, options: [
                Option('100', 100),
                Option('200', 200),
                Option('300', 300),
                Option('400', 400),
              ]),
              width: k.options('Width', initial: 100, options: [
                Option('100', 100),
                Option('200', 200),
                Option('300', 300),
                Option('400', 400),
              ]),
              color: k.options(
                'Color',
                initial: kLightNeutralBase,
                options: [
                  Option('Primary Base', kPrimaryBase),
                  Option('Success Base', kSuccessBase),
                  Option('Accent Base', kAccentBase),
                  Option('Warning Base', kWarningBase),
                  Option('Error Base', kErrorBase),
                  Option('Lighten5', kPrimaryLighten5),
                  Option('Lighten', kLightNeutralBase),
                ],
              ),
              shadowColor: k.options(
                'Shadow Color',
                initial: kLightBoxShadow,
                options: [
                  Option('Primary Base', kPrimaryBaseBoxShadow),
                  Option('Success Base', kSuccessBaseBoxShadow),
                  Option('Accent Base', kAccentBaseBoxShadow),
                  Option('Warning Base', kWarningBaseBoxShadow),
                  Option('Error Base', kErrorBaseBoxShadow),
                  Option('Light Base', kLightBoxShadow),
                  Option('Dark Base', kDarkBoxShadow),
                ],
              ),
              borderRadius: k.options('Border Radius', initial: 16, options: [
                Option('Very Large', 32),
                Option('Large', 24),
                Option('Small', 8),
                Option('Medium', 16),
                Option('Extreme', 40),
                Option('Rounded', 50),
              ]),
              blurRadius: k.options('Blur Radius', initial: 100, options: [
                Option('100', 100),
                Option('80', 80),
                Option('110', 110),
                Option('200', 200),
              ]),
              thickness: k.options('Border Thickness', initial: 0, options: [
                Option('0', 0),
                Option('1', 1),
                Option('1.5', 1.5),
                Option('2', 2),
                Option('3', 3),
                Option('4', 4),
              ]),
              borderColor: k.options(
                'Border Color',
                initial: kLightBoxShadow,
                options: [
                  Option('Primary Base', kPrimaryBase),
                  Option('Success Base', kSuccessBase),
                  Option('Accent Base', kAccentBase),
                  Option('Warning Base', kWarningBase),
                  Option('Error Base', kErrorBase),
                  Option('Light Base', kLightBoxShadow),
                  Option('Dark Base', kDarkBoxShadow),
                ],
              ),
            ),
          ),

          //buttons end
          // tooltip starts

          Story(
              background: kLightNeutralLighten0,
              section: 'ToolTip',
              name: 'Default ToolTip',
              padding: EdgeInsets.all(5),
              builder: (_, k) => DefaultToolTip(
                    borderRadius: 4,
                    arrowWidth: 13,
                    arrowHeight: 6,
                    padding: EdgeInsets.symmetric(horizontal: 10, vertical: 7),
                    direction: k.options('Direction',
                        initial: ArrowDirection.right,
                        options: [
                          Option('Left', ArrowDirection.left),
                          Option('Right', ArrowDirection.right),
                          Option('Bottom', ArrowDirection.bottom),
                          Option('Top', ArrowDirection.top),
                        ]),
                    text: k.text('Text', initial: 'I am a tooltip'),
                  )),

          Story(
            section: 'ToolTip',
            name: 'RothkoV2 Tooltip',
            builder: (_, k) => RothkoTooltip(
                content: [
                  Text(
                    'This is a tool tip',
                    style: RothkoTextStyles.caption.copyWith(
                        color: RothkoColor.kLightNeutralDarken1,
                        letterSpacing: 0.02,
                        fontWeight: FontWeight.w400),
                  ),
                ],
                triggerWidget: Icon(
                  Icons.info,
                  color: Colors.blue,
                ),
                direction:
                    k.options('Direction', initial: AxisDirection.up, options: [
                  Option('Left', AxisDirection.left),
                  Option('Right', AxisDirection.right),
                  Option('Bottom', AxisDirection.down),
                  Option('Top', AxisDirection.up),
                ]),
                toolTipHeight: 40.0),
          ),

          Story(
            section: 'ToolTip',
            name: 'V2 with Title',
            builder: (_, k) => RothkoTooltipWithTitle(
                title: 'This is the title',
                message: 'This is the message for the tooltip',
                triggerWidget: Icon(
                  Icons.info,
                  color: Colors.blue,
                ),
                direction:
                    k.options('Direction', initial: AxisDirection.up, options: [
                  Option('Left', AxisDirection.left),
                  Option('Right', AxisDirection.right),
                  Option('Bottom', AxisDirection.down),
                  Option('Top', AxisDirection.up),
                ]),
                toolTipHeight: 120.0),
          ),
          Story(
            section: 'ToolTip',
            name: 'V2 with Action',
            builder: (_, k) => RothkoTooltipWithAction(
                toolTipInfo: [],
                onDismiss: () {},
                stepperLength: 4,
                stepperPosition: 2,
                title: 'This is the title',
                message: 'This is the message for the tooltip',
                triggerWidget: Icon(
                  Icons.info,
                  color: Colors.blue,
                ),
                direction:
                    k.options('Direction', initial: AxisDirection.up, options: [
                  Option('Left', AxisDirection.left),
                  Option('Right', AxisDirection.right),
                  Option('Bottom', AxisDirection.down),
                  Option('Top', AxisDirection.up),
                ]),
                toolTipHeight: 200.0),
          ),

          //tooltip ends
          //date picker starts

          Story.simple(
            section: 'Picker',
            name: 'Date Picker',

            padding: EdgeInsets.all(5), // optional padding customization
            child: DatePicker(
              selectedValue: DateTime.now(),
              dateController: TextEditingController(),
              onChanged: (_) {},
            ),
          ),
          Story.simple(
            section: 'Picker',
            name: ' New Date Picker',

            padding: EdgeInsets.all(5), // optional padding customization
            child: NewDatePicker(
              selectedValue: DateTime.now(),
              onChanged: (_) {},
            ),
          ),
          Story.simple(
            section: 'Picker',
            name: 'TimePicker',
            padding: EdgeInsets.all(5), // optional padding customization
            child: TimePicker(
              selectedValue: DateTime.now(),
              timeController: TextEditingController(),
              onChanged: (_) {},
            ),
          ),

          //date picker end

          /// banner begins
          Story.simple(
            section: 'Banner',
            name: 'Rothko Fixed Banner',
            padding: EdgeInsets.all(5), // optional padding customization
            child: RothkoBanner(
              isDismissable: true,
              isInlineBanner: false,
              iconColor: RothkoColor.kWarningBase,
              bannerIcon: Icons.ac_unit,
              subHeading: 'Testing the header',
              bannerColor: RothkoColor.kWarningLighten2,
              message:
                  'Verify your account to increase your payroll limit and much more.',
              onPressed: () {},
            ),
          ),

          Story.simple(
            section: 'Banner',
            name: 'Banner withOutlineButton',
            padding: EdgeInsets.all(5), // optional padding customization
            child: BannerOutlineButton(
              message: 'Your email address is now connected to a Company.'
                  '\nContact your Company to get you started on Bento.',
            ),
          ),

          Story.simple(
            section: 'Banner',
            name: 'Banner withFilledButton',
            padding: EdgeInsets.all(5), // optional padding customization
            child: BannerFilledButton(
              message: 'Your email address is now connected to a Company.'
                  '\nContact your Company to get you started on Bento.',
            ),
          ),

          ///banners end

          //switches start

          Story(
              section: 'Switches',
              name: 'Switch',
              builder: (_, k) => Switches(
                    color: k.options(
                      'Color',
                      initial: kPrimaryBase,
                      options: [
                        Option('Primary Base', kPrimaryBase),
                        Option('Success Base', kSuccessBase),
                        Option('Accent Base', kAccentBase),
                        Option('Warning Base', kWarningBase),
                        Option('Error Base', kErrorBase),
                      ],
                    ),
                    disabled: k.boolean('Disabled', initial: false),
                  )),
          //switches end

          // toggle starts here
          Story(
            section: 'Toggle',
            name: 'Rothko Toggle',
            builder: (_, k) => RothkoToggle(
              onToggle: ((value) => print(value)),
              disabled: k.boolean('Disabled', initial: false),
              value: k.boolean('on/off', initial: false),

              isReadOnly: k.boolean('Readonly', initial: false),
              // activeIcon: k.options(
              //   'activeIcon',
              //   initial: SvgPicture.asset(
              //     "assets/svg/lock.svg",
              //     height: 750,
              //     width: 750,
              //     // fit: BoxFit.,
              //   ),
              //   options: [
              // Option(
              //   'Variation ee1',
              //   Image.network(
              //     "https://img2.pngio.com/functional-bits-in-flutter-flutter-community-medium-flutter-png-1000_1000.png",
              //   ),
              // ),
              // Option(
              //   'Variation 2 image',
              //   Image.network(
              //     "https://upload.wikimedia.org/wikipedia/commons/7/7e/Dart-logo.png",
              //   ),
              // ),
              //   ],
              // ),
              // inactiveIcon: Image.network(
              //   "https://upload.wikimedia.org/wikipedia/commons/7/7e/Dart-logo.png",
              // ),
            ),
          ),

          // toggle ends here

          //snackbar begins
          Story(
              section: 'Snackbar',
              name: 'Snackbar',
              builder: (_, k) => GestureDetector(
                    onTap: () {
                      Snackbar(
                        message: "",
                        learnMoreCallback: () {},
                        onStatusChanged: (status) {},
                        hasLearnMore:
                            k.options('hasLearnMore', initial: true, options: [
                          Option('true', true),
                          Option('false', false),
                        ]),
                        isCancelButton: k
                            .options('isCancelButton', initial: true, options: [
                          Option('true', true),
                          Option('false', false),
                        ]),
                        title: k.text('Title',
                            initial:
                                'I am a snack, a cute snack. Come take a bite, you will love it!'),
                        snackbarPosition: k.options("Position",
                            initial: SnackbarPosition.BOTTOM,
                            options: [
                              Option('TOP', SnackbarPosition.TOP),
                              Option('BOTTOM', SnackbarPosition.BOTTOM),
                            ]),
                        padding:
                            EdgeInsets.symmetric(vertical: 25, horizontal: 15),
                        margin:
                            EdgeInsets.symmetric(horizontal: 10, vertical: 20),
                        snackbarStyle: SnackbarStyle.FLOATING,
                        borderRadius: 8,
                        textColor: k.options('TextColor',
                            initial: RothkoColor.kLightNeutralLighten2,
                            options: [
                              Option('Primary Darken', kPrimaryDarken4),
                              Option('Success Darken', kSuccessDarken4),
                              Option('Warning Darken', kWarningDarken4),
                              Option('Accent Darken', kAccentDarken4),
                              Option('Error Darken', kErrorDarken4),
                              Option('Dark Base', kDarkNeutralBase),
                              Option('Light Neutral', kLightNeutralLighten0),
                            ]),
                        backgroundColor: k.options(
                          'Color',
                          initial: RothkoColor.kDarkNeutralDarken2,
                          options: [
                            Option('Primary Light', kPrimaryLighten5),
                            Option('Success Light', kSuccessLighten5),
                            Option('Accent Light', kAccentLighten5),
                            Option('Warning Light', kWarningLighten5),
                            Option('Error Light', kErrorLighten5),
                            Option('Primary Base', kPrimaryBase),
                            Option('Success Base', kSuccessBase),
                            Option('Accent Base', kAccentBase),
                            Option('Warning Base', kWarningBase),
                            Option('Error Base', kErrorBase),
                          ],
                        ),
                        fontSize: 12,
                        leftBarIndicatorColor: Colors.blue.shade300,
                        duration: Duration(seconds: 5),
                      )..show(context);
                    },
                    child: Container(
                      padding: EdgeInsets.all(15),
                      decoration: BoxDecoration(
                          color: kPrimaryBase,
                          borderRadius: BorderRadius.circular(10)),
                      child: Text(
                        "Show Snackbar",
                        style: TextStyle(color: kPrimaryLighten0),
                      ),
                    ),
                  )),
          Story(
              section: 'Snackbar',
              name: 'Snackbar With Icon',
              builder: (_, k) => GestureDetector(
                    onTap: () {
                      SnackbarHelper.withIcon(
                          title: "I am a snackbar",
                          message: "",
                          snackbarPosition: SnackbarPosition.BOTTOM,
                          snackbarStyle: SnackbarStyle.FLOATING,
                          textColor: k.options('TextColor',
                              initial: kPrimaryLighten0,
                              options: [
                                Option('Primary Darken', kPrimaryDarken4),
                                Option('Success Darken', kSuccessDarken4),
                                Option('Warning Darken', kWarningDarken4),
                                Option('Accent Darken', kAccentDarken4),
                                Option('Error Darken', kErrorDarken4),
                                Option('Dark Base', kDarkNeutralBase),
                                Option('Light Neutral', kLightNeutralLighten0),
                              ]),
                          bgColor: k.options(
                            'Color',
                            initial: kAccentBase,
                            options: [
                              Option('Primary Light', kPrimaryLighten5),
                              Option('Success Light', kSuccessLighten5),
                              Option('Accent Light', kAccentLighten5),
                              Option('Warning Light', kWarningLighten5),
                              Option('Error Light', kErrorLighten5),
                              Option('Primary Base', kPrimaryBase),
                              Option('Success Base', kSuccessBase),
                              Option('Accent Base', kAccentBase),
                              Option('Warning Base', kWarningBase),
                              Option('Error Base', kErrorBase),
                            ],
                          ),
                          icon: Icon(
                            Icons.info,
                            size: 28.0,
                            color: kPrimaryLighten0,
                          ),
                          trailingButton: GestureDetector(
                            onTap: () => print("works"),
                            child: Text(
                              "Close",
                              style: TextStyle(
                                  fontWeight: FontWeight.w700,
                                  fontFamily: "Proxima Nova",
                                  color: kPrimaryLighten0),
                            ),
                          ),
                          context: context)
                        ..show(context);
                    },
                    child: Container(
                      padding: EdgeInsets.all(15),
                      decoration: BoxDecoration(
                          color: kPrimaryBase,
                          borderRadius: BorderRadius.circular(10)),
                      child: Text(
                        "Show Snackbar With Icon",
                        style: TextStyle(color: kPrimaryLighten0),
                      ),
                    ),
                  )),

          ///end of banner
          ///begin Charts
          Story(
            section: 'Charts',
            name: 'Linear',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => ProgressLinear(
              percentage: k.text('Percentage', initial: '50.0'),
              backgroundColor: k.options(
                'background Color',
                initial: kPrimaryLighten5,
                options: [
                  Option('Primary', kPrimaryLighten5),
                  Option('Success', kSuccessLighten5),
                  Option('Accent', kAccentLighten5),
                  Option('Warning', kWarningLighten5),
                  Option('Error', kErrorLighten5),
                ],
              ),
              progressColor: k.options(
                'progress Color',
                initial: kPrimaryBase,
                options: [
                  Option('Primary', kPrimaryBase),
                  Option('Success', kSuccessBase),
                  Option('Accent', kAccentBase),
                  Option('Warning', kWarningBase),
                  Option('Error', kErrorBase),
                ],
              ),
            ),
          ),

          Story(
            section: 'Charts',
            name: 'Circular',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => ProgressCircular(
              percentage: k.text('Percentage', initial: '50.0'),
              size: k.options(
                'Radius',
                initial: 32.0,
                options: [
                  Option('small', 24.0),
                  Option('normal', 32.0),
                  Option('large', 40.0),
                  Option('Xlarge', 48.0),
                ],
              ),
              backgroundColor: k.options(
                'background Color',
                initial: kPrimaryLighten5,
                options: [
                  Option('Primary', kPrimaryLighten5),
                  Option('Success', kSuccessLighten5),
                  Option('Accent', kAccentLighten5),
                  Option('Warning', kWarningLighten5),
                  Option('Error', kErrorLighten5),
                ],
              ),
              lineWidth: k.options(
                'width',
                initial: 4.0,
                options: [
                  Option('4.0', 4.0),
                  Option('2.0', 2.0),
                ],
              ),
              progressColor: k.options(
                'progress Color',
                initial: kPrimaryBase,
                options: [
                  Option('Primary', kPrimaryBase),
                  Option('Success', kSuccessBase),
                  Option('Accent', kAccentBase),
                  Option('Warning', kWarningBase),
                  Option('Error', kErrorBase),
                ],
              ),
            ),
          ),

          ///Dialog starts
          ///
          Story.simple(
              padding: EdgeInsets.zero,
              name: 'Confirmation BottomSheet',
              section: 'Rothko BottomSheet',
              child: RothkoBottomSheetConfirmation(
                doubleCta: false,
                header: 'Header',
                body:
                    'Lorem ipsum dolor sit amet,consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.',
              )),
          Story.simple(
              padding: EdgeInsets.zero,
              name: 'Standard BottomSheet',
              section: 'Rothko BottomSheet',
              child: RothkoBottomSheetStandard(
                doubleCta: true,
                content: Container(
                  color: Colors.red,
                  height: MediaQuery.of(context).size.height * 0.4,
                  child: Text(
                    'This na the content, wey they expand',
                    textAlign: TextAlign.center,
                  ),
                ),
                header: 'header',
                subtitle: 'This is a subtitle',
              )),

          // Story.simple(
          //   section: 'Dialog',
          //   name: 'Rothko Dialogs',
          //   padding: EdgeInsets.all(5), // optional padding customization
          //   child: RothkoDialog(
          //       // onCancel: () {},
          //       // onCloseModal: () {},
          //       // onTapAction: () {},
          //       // withCancelButton: true,
          //       // message: 'Your request to enable Bento wallet has been received.'
          //       //     '\nA confirmation email has been sent to you.',
          //       ),
          // ),

          Story.simple(
            section: 'Dialog',
            name: 'Scrollable',
            padding: EdgeInsets.all(5), // optional padding customization
            child: DialogScrollable(),
          ),

          // Story.simple(
          //     section: 'Dialog',
          //     name: 'Form',
          //     padding: EdgeInsets.all(5), // optional padding customization
          //     child: DialogForm(
          //       children: [
          //         RothkoTextFieldDefault(
          //             label: 'label', readOnly: false, enabled: true),
          //         RothkoTextFieldDefault(
          //             label: 'label', readOnly: false, enabled: true),
          //         RothkoTextFieldDefault(
          //             label: 'label', readOnly: false, enabled: true),
          //         RothkoTextFieldDefault(
          //             label: 'label', readOnly: false, enabled: true),
          //       ],
          //       onTapAction: () {
          //         print("object");
          //       },
          //       noOfTextFields: 3,
          //       label: 'Sample',
          //     )),

          //switches end

          Story(
            section: 'Charts',
            name: 'Rotate',
            padding: EdgeInsets.all(5), // optional padding customization
            builder: (_, k) => ProgressRotate(
              percentage: k.text('Percentage', initial: '50'),
              radius: k.options(
                'Radius',
                initial: 48.0,
                options: [
                  Option('normal', 48.0),
                  Option('large', 56.0),
                  Option('Xlarge', 64.0),
                  Option('XXlarge', 72.0),
                ],
              ),
              percentFontSize: k.options(
                'percent Size',
                initial: 12.0,
                options: [
                  Option('normal', 12.0),
                  Option('large', 14.0),
                  Option('Xlarge/ XXlarge', 16.0),
                ],
              ),
              backgroundColor: k.options(
                'background Color',
                initial: kPrimaryLighten5,
                options: [
                  Option('Primary', kPrimaryLighten5),
                  Option('Success', kSuccessLighten5),
                  Option('Accent', kAccentLighten5),
                  Option('Warning', kWarningLighten5),
                  Option('Error', kErrorLighten5),
                ],
              ),
              progressColor: k.options(
                'progress Color',
                initial: kPrimaryBase,
                options: [
                  Option('Primary', kPrimaryBase),
                  Option('Success', kSuccessBase),
                  Option('Accent', kAccentBase),
                  Option('Warning', kWarningBase),
                  Option('Error', kErrorBase),
                ],
              ),
            ),
          ),

          ///MobileTabs
          Story.simple(
            section: 'Tabs',
            name: 'Tabs Default',
            padding: EdgeInsets.all(5), // optional padding customization
            child: MobileTabs(),
          ),
          Story.simple(
            section: 'Tabs',
            name: 'Tabs Dynamic',
            padding: EdgeInsets.all(5), // optional padding customization
            child: MobileTabsDynamic(
              tab: ['1', '2', '3', '4', '5', '6'],
              tabViews: [
                Container(
                  child: Center(child: Text('I am the first tabView widget')),
                ),
                Container(
                  child: Center(child: Text('I am the second tabView widget')),
                ),
                Container(
                  child: Center(child: Text('I am the third tabView widget')),
                ),
                Container(
                  child: Center(child: Text('I am the fourth tabView widget')),
                ),
                Container(
                  child: Center(child: Text('I am the fifth tabView widget')),
                ),
                Container(
                  child: Center(child: Text('I am the sixth tabView widget')),
                ),
              ],
            ),
          ),
        ],
      ));
}
